@@ -254,6 +254,8 @@ typedef struct
   GList *staff_directives;/**< List of DenemoDirective for the staff context, (only relevant for primary staff)*/
   GList *voice_directives;/**< List of DenemoDirective for the voice context */
   GString *lyrics_prolog;/**< (Unused)Customised version of the LilyPond prolog defining the lyrics of this staff */
+  GList *midi_events;/*< midi_events to be output at start of the track, after scorewide and movementwide ones */
+
   GString *figures_prolog;/**<  (Unused)Customised version of the LilyPond prolog defining the figured bass of this staff */
   GString *fakechords_prolog;/**<  (Unused)Customised version of the LilyPond prolog defining the chord symbols of this staff */
 }DenemoStaff;
@@ -313,7 +315,7 @@ typedef struct DenemoPrefs
   gboolean createclones;
 
   gboolean articulation_palette; /**< This switch makes the articulation pallete visable */
-  gboolean notation_palette; /**< This switch makes the duration toolbar visable */
+  gboolean notation_palette; /**< This switch makes the Note/Rest entry toolbar visable */
   gboolean rhythm_palette; /**< This option makes the rhythm toolbar visable */
   gboolean object_palette;  /**< This option makes the object menu toolbar visable */
 
@@ -330,11 +332,13 @@ typedef struct DenemoPrefs
   gboolean rtcs; /**< Real time csound */
   GString *sequencer;  /**< path to sequencer device */
   GString *midi_in;  /**< path to midi_in device */
-  gboolean *jacktransport; /**< toggle on and off jack transport */
-  gboolean *jacktransport_start_stopped; /**< toggle if you don't want transport to play immediately but rely on the transport controls */
-  gboolean *jack_at_startup; /**< toggle on and off jack initialization at startup */
+  gboolean jacktransport; /**< toggle on and off jack transport */
+  gboolean jacktransport_start_stopped; /**< toggle if you don't want transport to play immediately but rely on the transport controls */
+  gboolean jack_at_startup; /**< toggle on and off jack initialization at startup */
   GString *pdfviewer; /**< PDF viewer */
   GString *imageviewer; /**< Image Viewer */
+  GString *username; /**< Username for use on denemo.org website */
+  GString *password; /**< password  for use on denemo.org website (blank means prompt for username) */
   GString *texteditor; /**< texteditor for editing scripts and lilypond files */
   GString *denemopath; /**< path were denemo files are saved */
   GQueue *history; /**< Queue to contain recently opened files */
@@ -355,7 +359,7 @@ typedef struct DenemoDirective
   gint tx,ty; /**< x and y offsets in pixels for the display text */
   gint minpixels;/**< horizontal space needed by the display */
   gint x, y; /**< x and y offsets passed to LilyPond to control printed position */
-  GdkBitmap *graphic; /**< bitmap to draw for this directive */
+  gpointer graphic; /**< bitmap to draw for this directive, or for directives that cannot be drawn a widget to display for it */
   gint gx, gy; /**< x and y offsets in pixels for the graphic */
   GString *graphic_name; /**< name of the graphic to be drawn */
   gint width, height; /**< width and height of the bitmap */
@@ -637,7 +641,7 @@ typedef struct DenemoScore
   movementcontrol movementcontrol;/*< Directives for control of the whole movement */
   layout layout;/*< Directives for the layout block of the movement */
   header header;/*< Directives for the header block of the movement */
-  
+  GList *midi_events;/*< midi_events to be output at start of first track, after scorewide ones */
 
   guint changecount;
   /* Fields used for MIDI playback */
@@ -718,6 +722,7 @@ typedef struct DenemoGUI
 
   scoreheader scoreheader;/*< Directives for the header block at the start of the score */
   paper paper;/*< Directives for the paper block of the score */
+  GList *midi_events;/*< midi_events to be output at start of first track of each movement */
 
   GList *custom_scoreblocks; /**< List of customized texts for LilyPond output, replaces standard score blocks, elements are DenemoScoreblock * */
 
@@ -798,6 +803,7 @@ struct DenemoRoot
   gint accelerator_status; /**< if the accelerators have been saved, or extra ones for special keys defined  */
   GtkUIManager *ui_manager;  /**< UI manager */
   GtkWidget *window;
+  GtkWidget *console;/**< GtkTextView for console output */
   GtkActionGroup *action_group;/*< The action group for the actions that are Denemo commands */
   DenemoGUI *gui; /**< The current gui */
   GtkWidget *notebook;/**< contains the gui.page widgets */
