@@ -333,14 +333,14 @@ measureright (DenemoScriptParam *param)
 
 /**
  * swap the current movement for the previous one in the list of movements
- *
+ * return TRUE if movements are swapped
  */
 gboolean
 swapmovements (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
   if(!confirm_insertstaff_custom_scoreblock(gui))
-    return;
+    return FALSE;
   GList *this = g_list_find( gui->movements, gui->si);
   if(this->prev) {
     GList * prev = this->prev;
@@ -359,8 +359,10 @@ swapmovements (GtkAction *action, gpointer param)
     gchar *str = g_strdup_printf("This movement is now number %d in the score", 1+g_list_index(gui->movements, gui->si));
     infodialog(str);
     g_free(str);
+    return TRUE;
   } else
     warningdialog("There is no previous movement to swap with");
+  return FALSE;
 }
 /**
  * 
@@ -371,7 +373,7 @@ swapstaffs (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
   if(!confirm_insertstaff_custom_scoreblock(gui))
-    return;
+    return FALSE;
   if (gui->si->currentstaff && gui->si->currentstaff->prev)
     {
       DenemoStaff *temp;
@@ -404,7 +406,7 @@ splitstaffs (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
   if(!confirm_insertstaff_custom_scoreblock(gui))
-    return;
+    return FALSE;
   if (gui->si->currentstaff && gui->si->currentstaff->next)
     {
       DenemoStaff *thestaff = (DenemoStaff *)gui->si->currentstaff->data;
@@ -435,7 +437,7 @@ joinstaffs (GtkAction *action, gpointer param)
 {
   DenemoGUI  *gui = Denemo.gui;
   if(!confirm_insertstaff_custom_scoreblock(gui))
-    return;
+    return FALSE;
   if (gui->si->currentstaff && gui->si->currentstaff->prev)
     {
       DenemoStaff *thestaff = (DenemoStaff *)gui->si->currentstaff->data;
@@ -749,9 +751,9 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
     if(theobj->type == CHORD && ((chord*)theobj->object)->notes) {
       if(g_list_length( ((chord*)theobj->object)->notes)>1) {/* multi-note chord - remove and add a note */
 	gui->si->cursor_y = oldcursor_y;
-	tonechange(gui->si, TRUE);
+	delete_chordnote(gui->si);
 	gui->si->cursor_y = mid_c_offset;
-	tonechange(gui->si, FALSE);
+	insert_chordnote (gui->si);
       } else {/* single-note chord - change the note */
       gint dclef = find_prevailing_clef(gui->si);	    
       modify_note((chord*)theobj->object, mid_c_offset, gui->si->curmeasureaccs[note_value], dclef);
@@ -1013,15 +1015,15 @@ changeduration (DenemoScore * si, gint duration)
 }
 
 /**
- *  tonechange 
+ *  notechange 
  * If REMOVE delete the note closest to si->cursor_y in a ~si->currentobject
  * else add a note at si->cursor_y to the ~si->currentobject
- * FIXME ~si->currentobject in this comment means the thing gotten by the macro declaremudelaobj. This macro is a horrible hack induced by trying to be clever with tuplets - enforcing pairing of begin/end. tonechange 
+ * FIXME ~si->currentobject in this comment means the thing gotten by the macro declaremudelaobj. This macro is a horrible hack induced by trying to be clever with tuplets - enforcing pairing of begin/end. notechange 
  * @param si pointer to the scoreinfo structure
  * @param remove whether to remove note or not
  */
-gboolean
-tonechange (DenemoScore * si, gboolean remove)
+static gboolean
+notechange (DenemoScore * si, gboolean remove)
 {
   declarecurmudelaobj;
   int prognum;
@@ -1050,6 +1052,23 @@ tonechange (DenemoScore * si, gboolean remove)
   return ret;
 }
 
+/**
+ * Delete chord note closest to y cursor
+ */
+gboolean
+delete_chordnote (DenemoScore * si){
+  notechange(si, TRUE);
+  return TRUE;
+}
+/**
+ * Insert chord note at y cursor position 
+ */
+gboolean
+insert_chordnote (DenemoScore *si){
+  notechange(si, FALSE);
+  return TRUE;
+}
+
 /**
  * Helper function that contains calls to all the display 
  * update functions
