@@ -8,7 +8,6 @@
 
 
 
-#include "config.h"
 #include <denemo/denemo.h>
 #include "utils.h"
 #include <stdlib.h>
@@ -25,6 +24,7 @@
 #include "objops.h"
 #include "xmldefs.h"
 #include "lyric.h"
+#include "config.h"
 
 #define ENTER_NOTIFY_EVENT "focus-in-event"
 #define LEAVE_NOTIFY_EVENT "focus-out-event"
@@ -710,9 +710,11 @@ static gchar *get_postfix(GList *g) {
   GString *ret = g_string_new("");
   for(;g;g=g->next) {
     DenemoDirective *d = g->data;
-    
     if(d->postfix && d->postfix->len)
-      g_string_append(ret, d->postfix->str);
+      if(d->override & DENEMO_OVERRIDE_LILYPOND)
+	g_string_prepend(ret, d->postfix->str);
+      else
+	g_string_append(ret, d->postfix->str);
   }
 return g_string_free(ret, FALSE);
 }
@@ -724,8 +726,10 @@ static gchar *get_prefix(GList *g) {
   for(;g;g=g->next) {
     DenemoDirective *d = g->data;
     if(d->prefix && d->prefix->len)
-      g_string_append(ret, d->prefix->str);
-    
+      if(d->override & DENEMO_OVERRIDE_LILYPOND)
+	g_string_prepend(ret, d->prefix->str);
+      else
+	g_string_append(ret, d->prefix->str);
   }
 return g_string_free(ret, FALSE);
 }
@@ -735,17 +739,19 @@ return g_string_free(ret, FALSE);
 
 
 
-/* returns the directives flags ORd together */
+/* returns if there is a directive overriding the normal LilyPond output */
 static gint get_override(GList *g) {
   gint ret = 0;
   for(;g;g=g->next) {
     DenemoDirective *d = g->data;
     ret |= d->override;
   }
-  return ret;
+  return ret & DENEMO_OVERRIDE_LILYPOND;
 }
 
 
+
+
 /**
  * generate the lilypond for the DenemoObject curobj
  * the state of the prevailing duration, clef keysignature are updated and returned.
@@ -1780,7 +1786,7 @@ void delete_lily_cb (GtkAction *action, gpointer param) {
 
   gtk_text_buffer_delete(gui->textbuffer, &start, &end);
 }
-static gboolean print_lily_cb (GtkWidget *item, DenemoGUI *gui){
+static void print_lily_cb (GtkWidget *item, DenemoGUI *gui){
   gchar *filename = get_printfile_pathbasename();
   gchar *lilyfile = g_strconcat (filename, ".ly", NULL);
   FILE *fp = fopen(lilyfile, "w");
@@ -2056,18 +2062,12 @@ output_score_to_buffer (DenemoGUI *gui, gboolean all_movements, gchar * partname
 	  g_free(mvmnt_string);
 	}  
       }
-
-
-
+      /* the score prefix field is at the start of the whole score, the postfix field is placed as
+	 a prolog before the music in the scoreblock, unless the DENEMO_OVERRIDE_LILYPOND flag is set, in which case
+	 the postfix field replaces the scoreblock altogether */
       gchar *score_prolog = get_postfix(gui->lilycontrol.directives);
       g_string_append_printf (scoreblock, "%s", "\\score {\n");
-
-
-
       g_string_append_printf (scoreblock, "<<%s <<\n", score_prolog);
-
-
-
       g_free(score_prolog);
     }
  
@@ -2108,25 +2108,27 @@ output_score_to_buffer (DenemoGUI *gui, gboolean all_movements, gchar * partname
 				   movement_name->str, voice_name->str);
 	  
 	  GString *thestr = g_string_new("");
-	  gchar *staff_prolog_insert =  get_postfix(curstaffstruct->staff_directives);
+	  gchar *staff_prolog_insert =  get_prefix(curstaffstruct->staff_directives);
+	  gchar *staff_epilog_insert =  get_postfix(curstaffstruct->staff_directives);
 	  if(partname==NULL) {//when printing just one part, do not start/stop contexts
 	    if (curstaffstruct->context & DENEMO_CHOIR_START)
-	      g_string_append_printf(thestr, "\\new ChoirStaff %s << \n", staff_prolog_insert);
+	      g_string_append_printf(thestr, "\\new ChoirStaff %s << %s\n", staff_prolog_insert, staff_epilog_insert);
 	    if (curstaffstruct->context & DENEMO_GROUP_START)
-	      g_string_append_printf(thestr, "\\new StaffGroup %s << \n", staff_prolog_insert);
+	      g_string_append_printf(thestr, "\\new StaffGroup %s << %s\n", staff_prolog_insert, staff_epilog_insert);
 	    if (curstaffstruct->context & DENEMO_PIANO_START) /* Piano staff cannot start before Group */
-	      g_string_append_printf(thestr, "\\new PianoStaff %s << \n", staff_prolog_insert);
+	      g_string_append_printf(thestr, "\\new PianoStaff %s << %s\n", staff_prolog_insert, staff_epilog_insert);
 	  }
 	  if(curstaffstruct->voicenumber == 1) {
 	    if(!staff_override)
-	      g_string_append_printf(staffdefinitions, "%s%s = \\new Staff %s << {\n",movement_name->str, staff_name->str, staff_prolog_insert);
+	      g_string_append_printf(staffdefinitions, "%s%s = \\new Staff %s << %s{\n",movement_name->str, staff_name->str, staff_prolog_insert, staff_epilog_insert);
 	    else
-	      g_string_append_printf(staffdefinitions, "%s%s = %s",movement_name->str, staff_name->str, staff_prolog_insert);
+	      g_string_append_printf(staffdefinitions, "%s%s = %s%s",movement_name->str, staff_name->str, staff_prolog_insert, staff_epilog_insert);
 	    g_string_append_printf(thestr, "\\%s%s\n", movement_name->str, staff_name->str);
 	  }
 	  else
 	    g_string_append_printf(staffdefinitions, "%s", "\\new Voice {\n");
 	  g_free(staff_prolog_insert);
+	  g_free(staff_epilog_insert);
 
 	  if (curstaffstruct->no_of_lines != 5)
 	    g_string_append_printf(staffdefinitions, TAB "\\override Staff.StaffSymbol  #'line-count = #%d\n",
@@ -2244,9 +2246,28 @@ output_score_to_buffer (DenemoGUI *gui, gboolean all_movements, gchar * partname
       // Put this standard scoreblock in the textbuffer
 
       gtk_text_buffer_get_iter_at_mark(gui->textbuffer, &iter, gtk_text_buffer_get_mark(gui->textbuffer, STANDARD_SCOREBLOCK));
-      gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter,scoreblock->str, -1, INEDITABLE,
-						(partname==NULL && gui->custom_scoreblocks)?"invisible":NULL, NULL);
 
+#if 0
+      if(get_override(gui->lilycontrol.directives)) {
+	//FIXME this is being emitted for each movement, rather than just once
+	gchar *score_substitute = get_postfix(gui->lilycontrol.directives);
+	gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, score_substitute, -1, INEDITABLE, NULL);
+	g_free(score_substitute);
+      }
+#else
+      if(get_override(si->movementcontrol.directives)) {
+	gchar *scoreblock_substitute = get_postfix(si->movementcontrol.directives);
+	gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, scoreblock_substitute, -1, INEDITABLE, NULL);
+	g_free(scoreblock_substitute);
+      }
+
+#endif
+
+
+      else    
+	gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter,scoreblock->str, -1, INEDITABLE,
+						  (partname==NULL && gui->custom_scoreblocks)?"invisible":NULL, NULL);
+      
     }/* if visible movement */
 
     g_string_free(scoreblock, TRUE);
