@@ -236,7 +236,7 @@ LOOKUP(GROUP_END_STRING,DENEMO_GROUP_END)
 #define DO_INTDIREC(field) if (ELEM_NAME_EQ (childElem, #field))\
          directive->field = getXMLIntChild(childElem);
 
-static gint
+static void
 parseDirective (xmlNodePtr parentElem, xmlNsPtr ns,
 	       DenemoDirective *directive)
 {
@@ -266,34 +266,17 @@ parseDirective (xmlNodePtr parentElem, xmlNsPtr ns,
 }
 
 static gint
-parseWidgetDirective (xmlNodePtr parentElem, xmlNsPtr ns, gboolean *fn())
+parseWidgetDirective (xmlNodePtr parentElem, xmlNsPtr ns, gboolean *fn(), DenemoDirective *directive)
 {
-  DenemoDirective *directive = NULL;
   xmlNodePtr childElem;
-  gchar *graphic_name = NULL, *tag = NULL, *display = NULL;
-  FOREACH_CHILD_ELEM (childElem, parentElem) {
-    if(ELEM_NAME_EQ (childElem, "graphic_name")) {
-      graphic_name = xmlNodeListGetString (childElem->doc,
-						  childElem->xmlChildrenNode, 1);
+  
 
-  }
-    if(ELEM_NAME_EQ (childElem, "tag")) {
-      tag =  xmlNodeListGetString (childElem->doc,
-						  childElem->xmlChildrenNode, 1);
-  }
-    if(ELEM_NAME_EQ (childElem, "display")) {
-      display =  xmlNodeListGetString (childElem->doc,
-						  childElem->xmlChildrenNode, 1);
-  }
-  }
-  directive = fn(tag, graphic_name?graphic_name:display);
-  if(directive==NULL)
-    return;
   FOREACH_CHILD_ELEM (childElem, parentElem) {
     DO_DIREC(tag);
     DO_DIREC(prefix);
     DO_DIREC(postfix);
     DO_DIREC(display);
+    DO_DIREC(graphic_name);
 
     DO_DIREC(midibytes);
     DO_INTDIREC(override);
@@ -305,17 +288,8 @@ parseWidgetDirective (xmlNodePtr parentElem, xmlNsPtr ns, gboolean *fn())
     DO_INTDIREC(gx);
     DO_INTDIREC(gy);
   }
-
- 
-#if  0
-  FOREACH_CHILD_ELEM (childElem, parentElem) {
-    if(ELEM_NAME_EQ (childElem, "graphic_name")) {
-      directive->graphic_name =  g_string_new(xmlNodeListGetString (childElem->doc,
-						  childElem->xmlChildrenNode, 1));
-      directive = fn(directive->tag->str, directive->graphic_name->str );
-    }      
-  }
-#endif
+  widget_for_directive(directive,fn);
+  return TRUE;
 }
 
 
@@ -328,9 +302,9 @@ parseVerse (xmlNodePtr parentElem, xmlNsPtr ns,
 {
   gchar*   text = xmlNodeListGetString (parentElem->doc, parentElem->xmlChildrenNode, 1);
 
-  gtk_text_buffer_set_text (gtk_text_view_get_buffer (verse), text, -1);
+  gtk_text_buffer_set_text (gtk_text_view_get_buffer ((GtkTextView *) verse), text, -1);
   //gtk_text_buffer_set_modified(gtk_text_view_get_buffer(verse), FALSE);
-  g_signal_connect (G_OBJECT (gtk_text_view_get_buffer (verse)), "changed", G_CALLBACK (lyric_change), NULL);
+  g_signal_connect (G_OBJECT (gtk_text_view_get_buffer ((GtkTextView *)verse)), "changed", G_CALLBACK (lyric_change), NULL);
   g_free (text);
 }
 
@@ -359,14 +333,17 @@ parseDirectives (xmlNodePtr parentElem, xmlNsPtr ns)
   return directives;
 }
 
-static void
+static GList *
 parseWidgetDirectives (xmlNodePtr parentElem, xmlNsPtr ns, gboolean *fn())
 {
   GList *directives = NULL;
   xmlNodePtr childElem;
   FOREACH_CHILD_ELEM (childElem, parentElem) {
-    parseWidgetDirective(childElem, ns, fn);
+    DenemoDirective *directive = (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));
+    parseWidgetDirective(childElem, ns, fn, directive);
+    directives = g_list_append(directives, directive);
   }
+  return directives;
 }
 /**
  * Return the numerator and denominator from the given XML fraction.
@@ -475,34 +452,41 @@ determineAccidentalShift (gchar * accidentalName)
  * Parse the given <clef> element into a numeric clef type.
  */
 static void
-parseClef (xmlNodePtr clefElem, xmlNsPtr ns, gint * clefType)
+parseClef (xmlNodePtr clefElem, xmlNsPtr ns, clef * clef)
 {
   gchar *clefTypeName = (gchar *) xmlGetProp (clefElem, (xmlChar *) "name");
   if (clefTypeName == NULL)
     {
       g_warning ("No clef name specified; defaulting to treble");
-      *clefType = DENEMO_TREBLE_CLEF;
+      clef->type = DENEMO_TREBLE_CLEF;
     }
   else if (strcmp (clefTypeName, "treble") == 0)
-    *clefType = DENEMO_TREBLE_CLEF;
+    clef->type = DENEMO_TREBLE_CLEF;
   else if (strcmp (clefTypeName, "bass") == 0)
-    *clefType = DENEMO_BASS_CLEF;
+    clef->type = DENEMO_BASS_CLEF;
   else if (strcmp (clefTypeName, "alto") == 0)
-    *clefType = DENEMO_ALTO_CLEF;
+    clef->type = DENEMO_ALTO_CLEF;
   else if (strcmp (clefTypeName, "treble-8vb") == 0)
-    *clefType = DENEMO_G_8_CLEF;
+    clef->type = DENEMO_G_8_CLEF;
   else if (strcmp (clefTypeName, "tenor") == 0)
-    *clefType = DENEMO_TENOR_CLEF;
+    clef->type = DENEMO_TENOR_CLEF;
   else if (strcmp (clefTypeName, "soprano") == 0)
-    *clefType = DENEMO_SOPRANO_CLEF;
+    clef->type = DENEMO_SOPRANO_CLEF;
   else
     {
       g_warning ("Unknown clef type \"%s\"; defaulting to treble",
 		 clefTypeName);
-      *clefType = DENEMO_TREBLE_CLEF;
+      clef->type = DENEMO_TREBLE_CLEF;
     }
   g_free (clefTypeName);
-
+  xmlNodePtr childElem;
+  FOREACH_CHILD_ELEM (childElem, clefElem)
+    {
+      if(ELEM_NAME_EQ (childElem, "directives"))
+	{
+	  clef->directives = parseDirectives(childElem, ns);
+	}
+    }
 }
 
 
@@ -1697,7 +1681,7 @@ parseSetupInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoGUI * gui)
 	  }
 	else if (ELEM_NAME_EQ (childElem, "score-directives"))
 	  {
-	    /*gui->lilycontrol.directives =*/ parseWidgetDirectives(childElem, ns, score_directive_put_graphic);
+	    gui->lilycontrol.directives = parseWidgetDirectives(childElem, ns, score_directive_put_graphic);
 	  }
 
 
@@ -1735,7 +1719,7 @@ parseEditInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoScore * si,
 	  {
 	    cursorposition = getXMLIntChild (childElem);
 	    //g_print ("Cursor Pos %d\n", cursorposition);
-	    si->cursor_x = cursorposition;
+	    si->cursor_x = (cursorposition>0?cursorposition:0);//Is getting over written actually...
 	  }
       }
   }
@@ -2055,11 +2039,11 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
 	  }
 	else if (ELEM_NAME_EQ (childElem, "staff-directives"))
 	  {
-	    /*curStaff->staff_directives =*/ parseWidgetDirectives(childElem, ns, staff_directive_put_graphic);
+	    curStaff->staff_directives = parseWidgetDirectives(childElem, ns, staff_directive_put_graphic);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "voice-directives"))
 	  {
-	    /*curStaff->voice_directives =*/ parseWidgetDirectives(childElem, ns, voice_directive_put_graphic);
+	    curStaff->voice_directives = parseWidgetDirectives(childElem, ns, voice_directive_put_graphic);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "clef-directives"))
 	  {
@@ -2232,7 +2216,7 @@ parseInitVoiceParams (xmlNodePtr initVoiceParamsElem, xmlNsPtr ns,
 	  }
 	else if (ELEM_NAME_EQ (childElem, "clef"))
 	  {
-	    parseClef (childElem, ns, &(curVoice->clef.type));
+	    parseClef (childElem, ns, &curVoice->clef);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "key-signature"))
 	  {
@@ -2358,9 +2342,10 @@ parseMeasures (xmlNodePtr measuresElem, xmlNsPtr ns, DenemoScore * si)
 		}
 	      else if (ELEM_NAME_EQ (objElem, "clef"))
 		{
-		  parseClef (objElem, ns, (gint *) & newClef);
-		  curObj = dnm_newclefobj (newClef);
-		  currentClef = newClef;
+		  curObj = dnm_newclefobj (DENEMO_TREBLE_CLEF);
+		  parseClef (objElem, ns, curObj->object);
+		  
+		  currentClef = ((clef*)curObj->object)->type;
 		}
 	      else if (ELEM_NAME_EQ (objElem, "lyric"))
 		{
@@ -2603,15 +2588,15 @@ parseScore (xmlNodePtr scoreElem, xmlNsPtr ns, DenemoGUI * gui,
 
   childElem = getXMLChild (scoreElem, "header-directives", ns);
   if (childElem != 0)
-    /*si->header.directives =*/ parseWidgetDirectives(childElem, ns, header_directive_put_graphic);
+    si->header.directives = parseWidgetDirectives(childElem, ns, header_directive_put_graphic);
 
   childElem = getXMLChild (scoreElem, "layout-directives", ns);
   if (childElem != 0)
-    /*si->layout.directives =*/ parseWidgetDirectives(childElem, ns, layout_directive_put_graphic);
+    si->layout.directives = parseWidgetDirectives(childElem, ns, layout_directive_put_graphic);
 
   childElem = getXMLChild (scoreElem, "movementcontrol-directives", ns);
   if (childElem != 0)
-    /*si->movementcontrol.directives =*/ parseWidgetDirectives(childElem, ns, movementcontrol_directive_put_graphic);
+    si->movementcontrol.directives = parseWidgetDirectives(childElem, ns, movementcontrol_directive_put_graphic);
 
   childElem = getXMLChild (scoreElem, "score-info", ns);
   RETURN_IF_ELEM_NOT_FOUND ("score", childElem, "score-info");
@@ -2695,15 +2680,16 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
   /*  xmlNodePtr rootElem, childElem; */
   xmlNodePtr rootElem;
   gchar *version = NULL;
-
+  if(sXMLIDToElemMap != NULL) {
+    g_warning ("Recursive call to importXML - ignored\n");
+    return -1;
+  }
   /* Try to parse the file. */
 
   doc = xmlParseFile (filename);
-  if (doc == NULL)
-    {
+  if (doc == NULL) {
       g_warning ("Could not read XML file %s", filename);
-      ret = -1;
-      return ret;
+      return -1;
     }
 
   /*
@@ -2814,10 +2800,10 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
 	      parseSetupInfo(childElem, ns, gui);
 	    } else
 	      if (ELEM_NAME_EQ (childElem, "scoreheader-directives")){
-		/*gui->scoreheader.directives =*/ parseWidgetDirectives(childElem, ns, scoreheader_directive_put_graphic);
+		gui->scoreheader.directives = parseWidgetDirectives(childElem, ns, scoreheader_directive_put_graphic);
 	      } else
 		if (ELEM_NAME_EQ (childElem, "paper-directives")){
-		  /*gui->paper.directives =*/ parseWidgetDirectives(childElem, ns, paper_directive_put_graphic);
+		  gui->paper.directives = parseWidgetDirectives(childElem, ns, paper_directive_put_graphic);
 		} else
 		  if (ELEM_NAME_EQ (childElem, "custom_scoreblock")){
 		    gchar *tmp = (gchar *) xmlNodeListGetString (childElem->doc,
@@ -2888,11 +2874,11 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
     g_free (version);
   if (doc != NULL)
     xmlFreeDoc (doc);
-  g_hash_table_foreach (sXMLIDToElemMap, freeHashTableKey, NULL);
-  g_hash_table_destroy (sXMLIDToElemMap);
+  if(sXMLIDToElemMap != NULL) {
+    g_hash_table_foreach (sXMLIDToElemMap, freeHashTableKey, NULL);
+    g_hash_table_destroy (sXMLIDToElemMap);
+  }
   sXMLIDToElemMap = NULL;
-
-
   //g_print("Number of movements %d\n", g_list_length(gui->movements));
   return ret;
 }
