@@ -3,6 +3,9 @@
 #include "view.h"
 #include <string.h>
 
+/* merge types for command sets */
+#define DENEMO_MERGING (1<<0)
+#define DENEMO_INTERACTIVE (1<<1)
 
 static 	void show_type(GtkWidget *widget, gchar *message);
 /*
@@ -102,7 +105,7 @@ get_state (gchar * key)
 }
 
 /* add ui elements for menupath if missing */
-static gint
+static void
 instantiate_menus(gchar *menupath) {
   //g_print("Instantiate menus for %s\n", menupath);
  
@@ -111,17 +114,20 @@ instantiate_menus(gchar *menupath) {
   GtkWidget *widget = gtk_ui_manager_get_widget(Denemo.ui_manager, up1);
   if(widget==NULL)
     instantiate_menus(up1);
-  GtkAction *action = gtk_action_new(name,name,"A menu",NULL);
   GList *groups = gtk_ui_manager_get_action_groups (Denemo.ui_manager);
   GtkActionGroup *action_group = GTK_ACTION_GROUP(groups->data); //FIXME assuming the one we want is first
-  gtk_action_group_add_action(action_group, action);
-  g_object_set_data(G_OBJECT(action), "menupath", up1);
+  if(NULL == gtk_action_group_get_action(action_group, name)) {
+    GtkAction *action = gtk_action_new(name,name,"A menu",NULL);
+    gtk_action_group_add_action(action_group, action);
+    g_object_set_data(G_OBJECT(action), "menupath", up1);
+  }
   gtk_ui_manager_add_ui(Denemo.ui_manager,gtk_ui_manager_new_merge_id(Denemo.ui_manager), 
 			up1,
 			name, name, GTK_UI_MANAGER_MENU, FALSE);
   //g_print("Adding %s to %s\n", name, up1);
   // widget = gtk_ui_manager_get_widget(Denemo.ui_manager, menupath);
   //show_type (widget, "for menupath widget is ");
+  
 }
 
 void set_visibility_for_action(GtkAction *action, gboolean visible) {
@@ -142,11 +148,33 @@ static void hide_action_of_name(gchar *name){
   GtkAction *action = lookup_action_from_name (name);
   set_visibility_for_action(action, FALSE);
 }
+static void
+add_ui(gchar *menupath, gchar *after, gchar *name) {
+  GtkWidget *widget = gtk_ui_manager_get_widget(Denemo.ui_manager, menupath);
+  if(widget==NULL) {
+    instantiate_menus(menupath);
+  }
+  //We place the item after the "after" item in the menupath, unless that isn't yet
+  //installed, in which case we just append to the menu
+  gchar *menupath_item = g_build_filename(menupath,after,NULL);
+  GtkAction *sibling = gtk_ui_manager_get_action (Denemo.ui_manager, menupath_item);
+  if( (after!=NULL) & (sibling==NULL)) {
+    static gboolean once=TRUE;
+    if(once) {
+      gchar *msg = g_strdup_printf("Cannot place %s after %s as requested,\nbecause I haven't seen %s yet\nTo fix this delete the %s command save the command set,\nQuit and restart Denemo\nThen re-install %s by right clicking on the %s item\nand choosing Insert Command After This One\nAnd finally saving command set again", name, after, after, name, name, after);
+      infodialog(msg);
+      g_free(msg);
+      once = FALSE;
+    }
+  }
+  gtk_ui_manager_add_ui(Denemo.ui_manager,gtk_ui_manager_new_merge_id(Denemo.ui_manager),  sibling?menupath_item:menupath, name, name, GTK_UI_MANAGER_AUTO, FALSE);
+  g_free(menupath_item);
+}
 
 static void
-parseScripts (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *fallback, gboolean merge)
+parseScripts (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *fallback, gint merge)
 {
-  xmlChar *name=NULL, *menupath=NULL, *label=NULL, *tooltip=NULL, *scheme=NULL;
+  xmlChar *name=NULL, *menupath=NULL, *label=NULL, *tooltip=NULL, *scheme=NULL, *after=NULL;
   GList *menupaths = NULL;
   cur = cur->xmlChildrenNode;
   gint command_number = -1;
@@ -173,17 +201,7 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *fallbac
       } else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "scheme")) {
 	scheme = 
 	  xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
-#if 0
-	/* this puts the loaded script into the scheme view window - useful for development work */
-	if(merge && scheme) {
-	  GtkTextIter enditer;
-	  GtkTextBuffer *buffer = gtk_text_view_get_buffer((GtkTextView*)(Denemo.ScriptView));
-	  gtk_text_buffer_get_end_iter (buffer,  &enditer);
-	  gchar *text = g_strdup_printf(";;;Scheme code for command %s\n%s",name,scheme);
-	  gtk_text_buffer_insert(buffer, &enditer, text, -1);
-	  g_free(text); 
-	} 
-#endif 
+
 	is_script = TRUE;
       }    else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "hidden")) {
 	hidden = TRUE; 
@@ -198,6 +216,10 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *fallbac
 	label = 
 	  xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
       }
+      else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "after")) {
+	after = 
+	  xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
+      }
       else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "tooltip")) {
 	tooltip = 
 	  xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
@@ -216,8 +238,9 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *fallbac
 	    action = gtk_action_new(name,label,tooltip, icon_name);
 	    //g_print("New action %s\n", name);
 	    if(hidden)
-	      g_object_set_data(action, "hidden", TRUE);
-
+	      g_object_set_data(G_OBJECT(action), "hidden",  (gpointer)TRUE);
+	    if(after)
+	      g_object_set_data(G_OBJECT(action), "after", (gpointer)after);
 	    register_command(Denemo.map, action, name, label, tooltip, activate_script);
 	    GtkActionGroup *action_group;
 	    GList *groups = gtk_ui_manager_get_action_groups (Denemo.ui_manager);
@@ -231,27 +254,17 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *fallbac
 	      for(g=menupaths;g;g=g->next){
 		menupath = g->data;
 		menupath = menupath?menupath:(xmlChar*)"/MainMenu/Other";
-		GtkWidget *widget = gtk_ui_manager_get_widget(Denemo.ui_manager, menupath);
-		if(widget==NULL) {
-		  instantiate_menus(menupath);
-		}
-		  gtk_ui_manager_add_ui(Denemo.ui_manager,gtk_ui_manager_new_merge_id(Denemo.ui_manager), 
-				      menupath,
-				      name, name, GTK_UI_MANAGER_AUTO, FALSE);
+		add_ui(menupath, after, name);
 	      }
 	  } else {
 	    if(fallback) {/* no path given, use fallback */
 	      menupath = fallback;
-	      GtkWidget *widget = gtk_ui_manager_get_widget(Denemo.ui_manager, menupath);
-	      if(widget==NULL) {
-		instantiate_menus(menupath);
-	      }
-	      gtk_ui_manager_add_ui(Denemo.ui_manager,gtk_ui_manager_new_merge_id(Denemo.ui_manager), 
-				      menupath,
-				      name, name, GTK_UI_MANAGER_AUTO, FALSE);
+	      add_ui(menupath, after, name);
 	    }
 	  }
-	  if(merge && new_command) {
+	  if((merge&DENEMO_INTERACTIVE)
+	     && (merge&DENEMO_MERGING)
+	     && new_command) {
 	    gchar *msg = g_strdup_printf("Installed a command in the menu system\nat %s\n", menupath);
 	    infodialog(msg);
 	    g_free(msg);
@@ -402,7 +415,7 @@ parseCursors (xmlDocPtr doc, xmlNodePtr cur) {
 
 
 static void
-parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *menupath, gboolean merge)
+parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *menupath, gint merge)
 {
   xmlNodePtr ncur = cur->xmlChildrenNode;
   int i;
@@ -423,7 +436,7 @@ parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *menupa
 
 
 static void
-parseKeymap (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *menupath, gboolean merge)
+parseKeymap (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *menupath, gint merge)
 {
   for (cur = cur->xmlChildrenNode; cur != NULL;  cur = cur->next)
     {
@@ -464,6 +477,7 @@ gchar *extract_menupath(gchar *filename) {
 
 /* 
  * load a command from filename. 
+ * if not scripted and merging with other commands, tell the user where the new command is. 
  * If an action exists but has an empty script load the scheme script,
  if action is a new action leave script as empty string for loading on demand.
  * Create a widget for the action in a menupath found in filename or failing that deduced from
@@ -472,11 +486,11 @@ gchar *extract_menupath(gchar *filename) {
  * negative on failure
  */
 gint
-load_xml_keymap (gchar * filename)
+load_xml_keymap (gchar * filename, gboolean interactive)
 {
   keymap *the_keymap = Denemo.map; 
   gint ret = -1;
-  gboolean merge = FALSE;//Whether to replace the keymap or merge with it
+  gint merge = interactive?DENEMO_INTERACTIVE:0;//merge&DENEMO_MERGING is true if merging, merge&DENEMO_INTERACTIVE is true if not scripted
   xmlDocPtr doc;
   //xmlNsPtr ns;
   xmlNodePtr rootElem;
@@ -519,19 +533,19 @@ load_xml_keymap (gchar * filename)
 
       if ( (0 == xmlStrcmp (rootElem->name, (const xmlChar *) "commands")) ||
 	   (0 == xmlStrcmp (rootElem->name, (const xmlChar *) "keymap"))/* backward compatibility */ ||
-	   (merge = (0 == xmlStrcmp (rootElem->name, (const xmlChar *) "merge")))
-	  )
+	   ((merge |= DENEMO_MERGING*(0 == xmlStrcmp (rootElem->name, (const xmlChar *) "merge"))), merge&DENEMO_MERGING))
 	{
-	  if(!merge) {
+	  if(!(merge&DENEMO_MERGING)) {
 	    //g_print("Losing command set %p\n", Denemo.map);
 	    init_keymap(); 
 	    // g_print("Starting with a clean command set %p\n", Denemo.map);
 	  }
 	  parseKeymap (doc, rootElem, Denemo.map, menupath, merge);
-	  if(merge) {
+	  if(merge&DENEMO_MERGING) {
 	    if(Denemo.last_merged_command)
 	      g_free(Denemo.last_merged_command);
 	    Denemo.last_merged_command = g_strdup(filename);
+	    execute_init_scripts(menupath);
 	    //Denemo.accelerator_status = TRUE;
 	  }
 	  //if(!merge)
@@ -586,14 +600,14 @@ save_xml_keymap (gchar * filename)
 
   child = xmlNewChild (parent, NULL, (xmlChar *) "commands", NULL);
 
-  xmlNewTextChild (child, NULL, (xmlChar *) "title", (xmlChar *) "A Denemo Keymap");
+  xmlNewTextChild (child, NULL, (xmlChar *) "title", (xmlChar *) "A Denemo Command Set");
   xmlNewTextChild (child, NULL, (xmlChar *) "author", (xmlChar *) "AT, JRR, RTS");
 
   parent = xmlNewChild (child, NULL, (xmlChar *) "map", NULL);
 
   child = xmlNewChild (parent, NULL, (xmlChar *) "cursors", NULL);
 
-  g_hash_table_foreach(Denemo.map->cursors, output_pointer_shortcut, child);
+  g_hash_table_foreach(Denemo.map->cursors, (GHFunc)output_pointer_shortcut, child);
 
 
   for (i = 0; i < keymap_size(the_keymap); i++)
@@ -602,6 +616,7 @@ save_xml_keymap (gchar * filename)
      
       gpointer action = (gpointer)lookup_action_from_idx(the_keymap, i);
       gchar *scheme = action?g_object_get_data(action, "scheme"):NULL;
+      gchar *after = action?g_object_get_data(action, "after"):NULL;
       gboolean deleted = (gboolean) (action?g_object_get_data(action, "deleted"):NULL);
       gboolean hidden = (gboolean) (action?g_object_get_data(action, "hidden"):NULL);
       if(deleted && scheme)
@@ -615,7 +630,10 @@ save_xml_keymap (gchar * filename)
       g_print ("%s \n", name);
 #endif	
       xmlNewTextChild (child, NULL, (xmlChar *) "action",
-		       (xmlChar *) name);  
+		       (xmlChar *) name); 
+      if(after)
+	xmlNewTextChild (child, NULL, (xmlChar *) "after",
+			 (xmlChar *) after);  
       if(hidden)
 	xmlNewTextChild (child, NULL, (xmlChar *) "hidden", "true");
       if(scheme) 	
@@ -757,7 +775,7 @@ parse_paths (gchar * filename, DenemoGUI *gui)
 
 
 gint
-save_script_as_xml (gchar * filename, gchar *myname, gchar *myscheme, gchar *mylabel, gchar *mytooltip)
+save_script_as_xml (gchar * filename, gchar *myname, gchar *myscheme, gchar *mylabel, gchar *mytooltip, gchar *after)
 {
   xmlDocPtr doc;
   //xmlNsPtr ns;
@@ -774,7 +792,8 @@ save_script_as_xml (gchar * filename, gchar *myname, gchar *myscheme, gchar *myl
   parent = xmlNewChild (child, NULL, (xmlChar *) "map", NULL);
   
   child = xmlNewChild (parent, NULL, (xmlChar *) "row", NULL);
-  
+  xmlNewTextChild (child, NULL, (xmlChar *) "after",
+		   (xmlChar *) after);  
   
   xmlNewTextChild (child, NULL, (xmlChar *) "action",
 		   (xmlChar *) myname);  
