@@ -19,15 +19,36 @@
 #include "staffops.h"
 #include "utils.h"
 #include "prefops.h"
-
+#include "view.h"
 static void edit_directive_callback(GtkWidget *w, gpointer what);
 
 
+
+static DenemoDirective *get_movementcontrol_directive(gchar *tag);
+static DenemoDirective *get_score_directive(gchar *tag);
+
+static GHashTable *action_scripts;
+static void action_script_table_insert(gchar *name, gchar *script) {
+  if(!action_scripts)
+    action_scripts = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+  g_hash_table_insert(action_scripts, g_strdup(name), script);
+}
+
+void set_action_script_for_tag(gchar *tag, gchar *script) {
+  action_script_table_insert(tag, script);
+}
+static  gchar *get_action_script(gchar *name) {
+  if(action_scripts)
+    return (gchar *)g_hash_table_lookup(action_scripts, name);
+  return NULL;
+}
+
+
 static void
 gtk_menu_item_set_label_text(GtkMenuItem *item, gchar *text) {
-  GtkWidget *label = gtk_bin_get_child(item);
+  GtkWidget *label = (GtkWidget *)gtk_bin_get_child(GTK_BIN(item));
   if(label)
-    gtk_label_set_text(label, text);
+    gtk_label_set_text(GTK_LABEL(label), text);
 }
 
 
@@ -676,10 +697,10 @@ DenemoDirective *get_voice_directive(gchar *tag) {
 gboolean
 delete_staff_directive(gchar *tag) {
   if(Denemo.gui->si->currentstaff==NULL)
-    return;
+    return FALSE;
   DenemoStaff *curstaff = Denemo.gui->si->currentstaff->data;
   if(curstaff==NULL || curstaff->staff_directives==NULL)
-    return;
+    return FALSE;
   return delete_directive(&curstaff->staff_directives, tag);
 }
 
@@ -687,10 +708,10 @@ delete_staff_directive(gchar *tag) {
 gboolean
 delete_initialclef_directive(gchar *tag) {
   if(Denemo.gui->si->currentstaff==NULL)
-    return;
+    return FALSE;
   DenemoStaff *curstaff = Denemo.gui->si->currentstaff->data;
   if(curstaff==NULL || curstaff->clef.directives==NULL)
-    return;
+    return FALSE;
   return delete_directive(&curstaff->clef.directives, tag);
 }
 
@@ -734,6 +755,21 @@ gboolean delete_score_directive(gchar *tagname) {
   return delete_directive(&Denemo.gui->lilycontrol.directives, tagname);
 }
 
+
+#define GET_TAG_FUNC(what)\
+gchar *\
+what##_directive_get_tag(gchar *tag) {\
+  DenemoDirective *directive = get_##what##_directive(tag);\
+  if(directive)\
+    return directive->tag->str;\
+  else directive = get_##what##_directive(NULL);\
+  if(directive)\
+    return directive->tag->str;\
+  return NULL;\
+}
+
+
+
 #define GET_STR_FIELD_FUNC(what, field)\
 gchar *\
 what##_directive_get_##field(gchar *tag) {\
@@ -770,6 +806,29 @@ what##_directive_put_##field(gchar *tag, gchar *value) {\
 #define PUT_STR_FIELD_FUNCV(what, field) PUT_STR_FIELD_FUNC_NAME(what, field, voice_directives)
 
 
+
+
+GET_TAG_FUNC(standalone);
+GET_TAG_FUNC(chord);
+GET_TAG_FUNC(note);
+GET_TAG_FUNC(staff);
+GET_TAG_FUNC(voice);
+GET_TAG_FUNC(score);
+GET_TAG_FUNC(clef);
+GET_TAG_FUNC(timesig);
+GET_TAG_FUNC(keysig);
+GET_TAG_FUNC(scoreheader);
+GET_TAG_FUNC(header);
+GET_TAG_FUNC(paper);
+GET_TAG_FUNC(layout);
+GET_TAG_FUNC(movementcontrol);
+
+
+#undef GET_TAG_FUNC
+
+
+
+
 GET_STR_FIELD_FUNC(score, midibytes)
 GET_STR_FIELD_FUNC(movementcontrol, midibytes)
 GET_STR_FIELD_FUNC(note, midibytes)
@@ -778,12 +837,9 @@ GET_STR_FIELD_FUNC(staff, midibytes)
 GET_STR_FIELD_FUNC(voice, midibytes)
 GET_STR_FIELD_FUNC(standalone, midibytes)
 
-PUT_STR_FIELD_FUNC(score, midibytes)
-PUT_STR_FIELD_FUNC(movementcontrol, midibytes)
+
 PUT_STR_FIELD_FUNC(note, midibytes)
 PUT_STR_FIELD_FUNC(chord, midibytes)
-PUT_STR_FIELD_FUNCS(staff, midibytes)
-PUT_STR_FIELD_FUNCV(voice, midibytes)
 
 
 GET_STR_FIELD_FUNC(chord, prefix)
@@ -803,8 +859,6 @@ PUT_STR_FIELD_FUNC(note, prefix)
 PUT_STR_FIELD_FUNC(note, postfix)
 PUT_STR_FIELD_FUNC(note, display)
 
-PUT_STR_FIELD_FUNC(score, prefix)
-PUT_STR_FIELD_FUNC(score, postfix)
 
 
 GET_STR_FIELD_FUNC(standalone, prefix)
@@ -819,16 +873,12 @@ GET_STR_FIELD_FUNC(staff, prefix)
 GET_STR_FIELD_FUNC(staff, postfix)
 GET_STR_FIELD_FUNC(staff, display)
 
-PUT_STR_FIELD_FUNCS(staff, prefix)
-PUT_STR_FIELD_FUNCS(staff, postfix)
 
 
 GET_STR_FIELD_FUNC(voice, prefix)
 GET_STR_FIELD_FUNC(voice, postfix)
 GET_STR_FIELD_FUNC(voice, display)
 
-PUT_STR_FIELD_FUNCV(voice, prefix)
-PUT_STR_FIELD_FUNCV(voice, postfix)
 
 #undef staff
 
@@ -867,18 +917,18 @@ what##_directive_get_##field(gchar *tag) {\
      /* block which can be copied for new int fields */
 PUT_INT_FIELD_FUNC(note, minpixels)
 PUT_INT_FIELD_FUNC(chord, minpixels)
-PUT_INT_FIELD_FUNCS(staff, minpixels)
-PUT_INT_FIELD_FUNCV(voice, minpixels)
-PUT_INT_FIELD_FUNC(score, minpixels)
+     //PUT_INT_FIELD_FUNCS(staff, minpixels)
+     //PUT_INT_FIELD_FUNCV(voice, minpixels)
+     //PUT_INT_FIELD_FUNC(score, minpixels)
 PUT_INT_FIELD_FUNC(clef, minpixels)
 PUT_INT_FIELD_FUNC(timesig, minpixels)
 PUT_INT_FIELD_FUNC(keysig, minpixels)
 
-PUT_INT_FIELD_FUNC(scoreheader, minpixels)
-PUT_INT_FIELD_FUNC(header, minpixels)
-PUT_INT_FIELD_FUNC(paper, minpixels)
-PUT_INT_FIELD_FUNC(layout, minpixels)
-PUT_INT_FIELD_FUNC(movementcontrol, minpixels)
+     //PUT_INT_FIELD_FUNC(scoreheader, minpixels)
+     //PUT_INT_FIELD_FUNC(header, minpixels)
+     //PUT_INT_FIELD_FUNC(paper, minpixels)
+     //PUT_INT_FIELD_FUNC(layout, minpixels)
+     //PUT_INT_FIELD_FUNC(movementcontrol, minpixels)
 
      //standalone needs different code for "put" see STANDALONE_PUT* below
 GET_INT_FIELD_FUNC(note, minpixels)
@@ -908,9 +958,7 @@ GET_INT_FIELD_FUNC(standalone, minpixels)
 
 PUT_INT_FIELD_FUNC(note, override)
 PUT_INT_FIELD_FUNC(chord, override)
-PUT_INT_FIELD_FUNCS(staff, override)
-PUT_INT_FIELD_FUNCV(voice, override)
-PUT_INT_FIELD_FUNC(score, override)
+
 GET_INT_FIELD_FUNC(note, override)
 GET_INT_FIELD_FUNC(chord, override)
 GET_INT_FIELD_FUNC(staff, override)
@@ -922,8 +970,7 @@ GET_INT_FIELD_FUNC(score, override)
 
 PUT_INT_FIELD_FUNC(note, x)
 PUT_INT_FIELD_FUNC(chord, x)
-PUT_INT_FIELD_FUNCS(staff, x)
-PUT_INT_FIELD_FUNCV(voice, x)
+
 
 GET_INT_FIELD_FUNC(note, x)
 GET_INT_FIELD_FUNC(chord, x)
@@ -932,8 +979,7 @@ GET_INT_FIELD_FUNC(voice, x)
  
 PUT_INT_FIELD_FUNC(note, y)
 PUT_INT_FIELD_FUNC(chord, y)
-PUT_INT_FIELD_FUNCS(staff, y)
-PUT_INT_FIELD_FUNCV(voice, y)
+
 
 GET_INT_FIELD_FUNC(note, y)
 GET_INT_FIELD_FUNC(chord, y)
@@ -943,8 +989,7 @@ GET_INT_FIELD_FUNC(voice, y)
 
 PUT_INT_FIELD_FUNC(note, tx)
 PUT_INT_FIELD_FUNC(chord, tx)
-PUT_INT_FIELD_FUNCS(staff, tx)
-PUT_INT_FIELD_FUNCV(voice, tx)
+
 GET_INT_FIELD_FUNC(note, tx)
 GET_INT_FIELD_FUNC(chord, tx)
 GET_INT_FIELD_FUNC(staff, tx)
@@ -952,8 +997,7 @@ GET_INT_FIELD_FUNC(voice, tx)
 
 PUT_INT_FIELD_FUNC(note, ty)
 PUT_INT_FIELD_FUNC(chord, ty)
-PUT_INT_FIELD_FUNCS(staff, ty)
-PUT_INT_FIELD_FUNCV(voice, ty)
+
 GET_INT_FIELD_FUNC(note, ty)
 GET_INT_FIELD_FUNC(chord, ty)
 GET_INT_FIELD_FUNC(staff, ty)
@@ -962,8 +1006,7 @@ GET_INT_FIELD_FUNC(voice, ty)
 
 PUT_INT_FIELD_FUNC(note, gx)
 PUT_INT_FIELD_FUNC(chord, gx)
-PUT_INT_FIELD_FUNCS(staff, gx)
-PUT_INT_FIELD_FUNCV(voice, gx)
+
 GET_INT_FIELD_FUNC(note, gx)
 GET_INT_FIELD_FUNC(chord, gx)
 GET_INT_FIELD_FUNC(staff, gx)
@@ -972,8 +1015,7 @@ GET_INT_FIELD_FUNC(voice, gx)
 
 PUT_INT_FIELD_FUNC(note, gy)
 PUT_INT_FIELD_FUNC(chord, gy)
-PUT_INT_FIELD_FUNCS(staff, gy)
-PUT_INT_FIELD_FUNCV(voice, gy)
+
 GET_INT_FIELD_FUNC(note, gy)
 GET_INT_FIELD_FUNC(chord, gy)
 GET_INT_FIELD_FUNC(staff, gy)
@@ -999,18 +1041,6 @@ GET_INT_FIELD_FUNC(score, ty)
 GET_INT_FIELD_FUNC(score, gx)
 GET_INT_FIELD_FUNC(score, gy)
 
-PUT_INT_FIELD_FUNC(score, x)
-PUT_INT_FIELD_FUNC(score, y)
-
-PUT_INT_FIELD_FUNC(score, tx)
-PUT_INT_FIELD_FUNC(score, ty)
-
-PUT_INT_FIELD_FUNC(score, gx)
-PUT_INT_FIELD_FUNC(score, gy)
-PUT_INT_FIELD_FUNC(score, width)
-PUT_INT_FIELD_FUNC(score, height)
-
-
 
      /* width and height of graphic (if any), read only */
 GET_INT_FIELD_FUNC(note, width)
@@ -1040,134 +1070,358 @@ what##_directive_put_graphic(gchar *tag, gchar *value) {\
     directive=new_directive(tag);\
     current->directives = g_list_append(current->directives, directive);\
     }\
-  loadGraphicItem(value, &directive->graphic, &directive->width, &directive->height);\
+  loadGraphicItem(value, (GdkBitmap **)&directive->graphic, &directive->width, &directive->height);\
   if(directive->graphic_name)\
      g_string_assign(directive->graphic_name, value);\
   else\
       directive->graphic_name = g_string_new(value);\
   return TRUE;\
 }
+#define PUT_GRAPHIC(what) PUT_GRAPHIC_NAME(what, directives)
+PUT_GRAPHIC(chord);
+PUT_GRAPHIC(note);
 
+/* return a full path to an editscript for directive or NULL if there is none */
+static gchar *get_editscript_filename(gchar *tag) {
+gchar *basename = g_strconcat(tag, ".scm", NULL);
+  gchar* filename = g_build_filename (locatedotdenemo(), "actions", "editscripts", basename, NULL);
+  if(!g_file_test(filename, G_FILE_TEST_EXISTS)) {
+    g_free(filename);
+    filename = g_build_filename(get_data_dir(), "actions", "editscripts", basename, NULL);
+    if(!g_file_test(filename, G_FILE_TEST_EXISTS)) {
+      g_free(filename);
+      filename = g_build_filename (locatedotdenemo(), "download", "actions", "editscripts", basename, NULL);
+      if(!g_file_test(filename, G_FILE_TEST_EXISTS)){
+	g_free(filename);
+	g_free(basename);
+	return NULL;
+      }
+    }
+  }
+  g_free(basename);
+  return filename;
+}
+
+static void
+runscript_callback (GtkWidget *w, DenemoDirective *directive){
+gchar *editscript = get_editscript_filename(directive->tag->str);
+ if(editscript)
+   execute_script_file(editscript);
+ else
+   g_warning("Editscript has vanished");
+ g_free(editscript);
+}
+
+static void
+action_script_callback (GtkWidget *w, DenemoDirective *directive){
+gchar *actionscript = get_action_script(directive->tag->str);
+ if(actionscript)
+   call_out_to_guile(actionscript);
+ else
+   g_warning("action script has vanished");
+}
+
+static void
+button_callback (GtkWidget *w, DenemoDirective *directive){
+gchar *script = get_action_script(directive->tag->str);
+ if(script)
+   call_out_to_guile(script);
+ else {
+   script = get_editscript_filename(directive->tag->str);
+   if(script)
+     execute_script_file(script);
+   else {
+     gpointer fn = g_object_get_data(G_OBJECT(w), "fn");
+     if(fn)
+       edit_directive_callback(w, fn);
+   }
+ }
+}
 /*
-  label_widget()
+  widget_for_directive()
   if directive does not have graphic:
-     fn gives the type of directive, which must be a non-DenemoObject directive: it determines where the widget goes (score or movement level, DenemoGUI or DenemoScore respectively).
-     field must be "display" or "graphic_name"
-     creates a widget (button or menu depending on fn) for editing directive, point directive->graphic to it and attach a callback to edit this directive, passing fn as data to it (to say what sort of directive it is).
-     places the widget in the appropriate buttonbox.
-  if directive does have graphic:
-     fn and field are ignored.
-  In all cases:
+     fn gives the type of directive, which must be a non-DenemoObject directive: it determines where the widget goes (score or movement level, DenemoGUI or DenemoScore respectively, or in staff or voice menu)
+     
+     creates a widget (button or menu depending on fn) for editing/actioning directive, point directive->graphic to it and attach a callback to edit/action this directive, passing fn as data to it (to say what sort of directive it is) or the directive itself (for actionscripts/editscripts).
+   places the widget in the appropriate buttonbox.
+
      set  the label for the widget from directive->graphic_name directive->display
+     set  the visibility for the widget from directive->override
 
 */
      
-static void 
-label_widget(DenemoDirective *directive,  void fn(), gchar *field) {
+void 
+widget_for_directive(DenemoDirective *directive,  void fn()) {
   GtkWidget *box;
-  gchar *value = g_strdup_printf("%s%s",directive->graphic_name?directive->graphic_name->str:"" , 
-				 directive->display?directive->display->str:"");
-
-  //  g_print("Have value %s\n", value);
-  //if this is not the display field, but the graphic that is being set, create the graphic
-  if((directive->graphic==NULL) && *value && strcmp(field, "display") ) {
-    if(fn==score_directive_put_graphic ||fn==scoreheader_directive_put_graphic ||fn==paper_directive_put_graphic)  
+  gchar *value = directive->display?directive->display->str:"";
+  if((directive->graphic==NULL) ) {
+    if(fn==(void(*)())score_directive_put_graphic ||fn==(void(*)())scoreheader_directive_put_graphic ||fn==(void(*)())paper_directive_put_graphic)  
       box = Denemo.gui->buttonbox;
     else
       box = Denemo.gui->si->buttonbox;
-    if(fn==staff_directive_put_graphic) {
+    if(fn==(void(*)())staff_directive_put_graphic) {
       //g_print("Doing the staff case");
-      directive->graphic = gtk_menu_item_new_with_label(value);
+      directive->graphic = (gpointer)gtk_menu_item_new_with_label(value);
       /* g_print("directive-type %s.....", thetype);	*/
       GtkWidget *menu;
-      menu = ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->staffmenu;
+      menu = (GtkWidget *)((DenemoStaff*)Denemo.gui->si->currentstaff->data)->staffmenu;
       g_signal_connect(G_OBJECT(directive->graphic), "activate",  G_CALLBACK(edit_directive_callback), fn);
       gtk_menu_shell_append(GTK_MENU_SHELL(menu), directive->graphic);
     } else    
-      if(fn==voice_directive_put_graphic) {
+      if(fn==(void(*)())voice_directive_put_graphic) {
 	//g_print("Doing the voice case");
 	directive->graphic = gtk_menu_item_new_with_label(value);//WARNING _with_label is important
 	/* g_print("directive-type %s.....", thetype);	*/
 	GtkWidget *menu;
-	menu = ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->voicemenu;  
+	menu = (GtkWidget *)((DenemoStaff*)Denemo.gui->si->currentstaff->data)->voicemenu;  
 	g_signal_connect(G_OBJECT(directive->graphic), "activate",  G_CALLBACK(edit_directive_callback), fn);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), directive->graphic);
       }  else {
 	//g_print("Doing the non-staff case");
+	//DISTINGUISH TWO CASES HERE if there is an editscript for directive->tag then use that for the callback and if there is a graphic with name directive->graphic_name then use that as an icon for the button widget coming next.
+	gchar *editscript = get_editscript_filename(directive->tag->str);
+	//FIXME look for a graphic of graphic_name & place it on button as icon ...
+     
 	directive->graphic = gtk_button_new_with_label(value);
-	g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(edit_directive_callback), fn);
+	{
+	  GtkWidget *label = gtk_bin_get_child(directive->graphic);
+	  //g_print("%s%s\n","type is", label?g_type_name(G_TYPE_FROM_INSTANCE(label)):"NULL widget");
+	  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	}
+#if 0
+	{
+	  GtkImage *image = gtk_image_new_from_pixbuf(pixbuf);
+	  gtk_button_set_image(button, image);
+	}
+#endif
+
+#if 1
+	g_object_set_data(G_OBJECT(directive->graphic), "fn", (gpointer)fn);
+	g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(button_callback), directive);
+#else
+	gchar *actionscript = get_action_script(directive->tag->str);
+	if(actionscript)
+	  g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(action_script_callback), directive); else	
+	    if(editscript) 
+	      g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(runscript_callback), directive);
+	    else
+	      g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(edit_directive_callback), fn);
+#endif
+	g_free(editscript);
 	gtk_box_pack_start (GTK_BOX (box), directive->graphic, FALSE, TRUE,0);
-	gtk_widget_show(directive->graphic);
+	g_object_set_data(directive->graphic, "directive", (gpointer)directive);
 	gtk_widget_show(box);
       }
-    g_object_set_data(directive->graphic, "directive", (gpointer)directive);
-    gtk_widget_show_all(GTK_WIDGET(directive->graphic));
     GTK_WIDGET_UNSET_FLAGS(directive->graphic, GTK_CAN_FOCUS);
-  }//not display field
-  if(directive->graphic){
-    if(GTK_IS_BUTTON(directive->graphic))
-      gtk_button_set_label(directive->graphic, value);
-    else
-      gtk_menu_item_set_label_text(directive->graphic, value);
-  }
-  g_free(value);
+  }//no graphic
+  (directive->override&DENEMO_OVERRIDE_GRAPHIC)?gtk_widget_show(directive->graphic):gtk_widget_hide(directive->graphic);
+  if(GTK_IS_MENU_ITEM(directive->graphic))
+    gtk_menu_item_set_label_text(directive->graphic, value);
+  else
+    gtk_label_set_markup((GtkLabel *)gtk_bin_get_child(GTK_BIN(directive->graphic)), value);
 }
 
 
 // create a directive for non-DenemoObject directive #what
-// create a button to edit the directive as the directive->graphic
-#define PUT_GRAPHIC_WIDGET_FUNC(field, field_name, what, directives) gpointer \
+// create a button to edit/action the directive as the directive->graphic
+#define PUT_GRAPHIC_WIDGET_STR(field, what, directives_name) gpointer \
 what##_directive_put_##field(gchar *tag, gchar *value) {\
   what *current = get_##what();\
   if(current==NULL) return NULL;\
-  if(current->directives==NULL)\
-       create_directives (&current->directives, tag);\
+  if(current->directives_name==NULL)\
+       create_directives (&current->directives_name, tag);\
   DenemoDirective *directive = get_##what##_directive(tag);\
   if(directive==NULL){\
     directive=new_directive(tag);\
-    current->directives = g_list_append(current->directives, directive);\
+    current->directives_name = g_list_append(current->directives_name, directive);\
     }\
-  if(directive->field_name==NULL) \
-    directive->field_name = g_string_new(value);\
+  if(directive->field==NULL) \
+    directive->field = g_string_new(value);\
   else\
-    g_string_assign(directive->field_name, value);\
-  label_widget(directive, what##_directive_put_graphic, #field);\
+    g_string_assign(directive->field, value);\
+  widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
   return (gpointer)directive;\
 }
 
+#define PUT_GRAPHIC_WIDGET_INT(field, what, directives_name)\
+gboolean \
+what##_directive_put_##field(gchar *tag, gint value) {\
+  what *current = get_##what();\
+  if(current==NULL) return FALSE;\
+  if(current->directives_name==NULL)\
+       create_directives (&current->directives_name, tag);\
+  DenemoDirective *directive = get_##what##_directive(tag);\
+  if(directive==NULL){\
+    directive=new_directive(tag);\
+    current->directives_name = g_list_append(current->directives_name, directive);\
+    }\
+ directive->field = value;\
+ widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
+ return TRUE;\
+}
+
+//FIXME this is just storing the graphic name, it can be placed on the button/menu item as an icon
+#define PUT_GRAPHIC_WIDGET_GRAPHIC(what, directives_name) gpointer \
+what##_directive_put_graphic(gchar *tag, gchar *value) {\
+  what *current = get_##what();\
+  if(current==NULL) return NULL;\
+  if(current->directives_name==NULL)\
+       create_directives (&current->directives_name, tag);\
+  DenemoDirective *directive = get_##what##_directive(tag);\
+  if(directive==NULL){\
+    directive=new_directive(tag);\
+    current->directives_name = g_list_append(current->directives_name, directive);\
+    }\
+  if(directive->graphic_name==NULL) \
+    directive->graphic_name = g_string_new(value);\
+  else\
+    g_string_assign(directive->graphic_name, value);\
+  widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
+  return (gpointer)directive;\
+}
+
+PUT_GRAPHIC_WIDGET_GRAPHIC( score, directives)
+PUT_GRAPHIC_WIDGET_GRAPHIC( scoreheader, directives)
+PUT_GRAPHIC_WIDGET_GRAPHIC( header, directives)
+PUT_GRAPHIC_WIDGET_GRAPHIC( paper, directives)
+PUT_GRAPHIC_WIDGET_GRAPHIC( layout, directives)
+PUT_GRAPHIC_WIDGET_GRAPHIC( movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_GRAPHIC( staff, staff_directives)
+PUT_GRAPHIC_WIDGET_GRAPHIC( voice, voice_directives)
 
 
-#define PUT_GRAPHIC(what) PUT_GRAPHIC_NAME(what, directives)
-#define PUT_GRAPHICS(what) PUT_GRAPHIC_NAME(what, staff_directives)
-#define PUT_GRAPHICV(what) PUT_GRAPHIC_NAME(what, voice_directives)
+PUT_GRAPHIC_WIDGET_STR(display, score, directives)
+PUT_GRAPHIC_WIDGET_STR(display, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_STR(display, header, directives)
+PUT_GRAPHIC_WIDGET_STR(display, paper, directives)
+PUT_GRAPHIC_WIDGET_STR(display, layout, directives)
+PUT_GRAPHIC_WIDGET_STR(display, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_STR(display, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_STR(display, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_STR(prefix, score, directives)
+PUT_GRAPHIC_WIDGET_STR(prefix, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_STR(prefix, header, directives)
+PUT_GRAPHIC_WIDGET_STR(prefix, paper, directives)
+PUT_GRAPHIC_WIDGET_STR(prefix, layout, directives)
+PUT_GRAPHIC_WIDGET_STR(prefix, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_STR(prefix, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_STR(prefix, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_STR(postfix, score, directives)
+PUT_GRAPHIC_WIDGET_STR(postfix, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_STR(postfix, header, directives)
+PUT_GRAPHIC_WIDGET_STR(postfix, paper, directives)
+PUT_GRAPHIC_WIDGET_STR(postfix, layout, directives)
+PUT_GRAPHIC_WIDGET_STR(postfix, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_STR(postfix, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_STR(postfix, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_STR(midibytes, score, directives)
+PUT_GRAPHIC_WIDGET_STR(midibytes, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_STR(midibytes, header, directives)
+PUT_GRAPHIC_WIDGET_STR(midibytes, paper, directives)
+PUT_GRAPHIC_WIDGET_STR(midibytes, layout, directives)
+PUT_GRAPHIC_WIDGET_STR(midibytes, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_STR(midibytes, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_STR(midibytes, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(minpixels, score, directives)
+PUT_GRAPHIC_WIDGET_INT(minpixels, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(minpixels, header, directives)
+PUT_GRAPHIC_WIDGET_INT(minpixels, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(minpixels, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(minpixels, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(minpixels, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(minpixels, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(x, score, directives)
+PUT_GRAPHIC_WIDGET_INT(x, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(x, header, directives)
+PUT_GRAPHIC_WIDGET_INT(x, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(x, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(x, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(x, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(x, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(y, score, directives)
+PUT_GRAPHIC_WIDGET_INT(y, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(y, header, directives)
+PUT_GRAPHIC_WIDGET_INT(y, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(y, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(y, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(y, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(y, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(tx, score, directives)
+PUT_GRAPHIC_WIDGET_INT(tx, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(tx, header, directives)
+PUT_GRAPHIC_WIDGET_INT(tx, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(tx, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(tx, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(tx, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(tx, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(ty, score, directives)
+PUT_GRAPHIC_WIDGET_INT(ty, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(ty, header, directives)
+PUT_GRAPHIC_WIDGET_INT(ty, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(ty, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(ty, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(ty, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(ty, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(gx, score, directives)
+PUT_GRAPHIC_WIDGET_INT(gx, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(gx, header, directives)
+PUT_GRAPHIC_WIDGET_INT(gx, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(gx, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(gx, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(gx, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(gx, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(gy, score, directives)
+PUT_GRAPHIC_WIDGET_INT(gy, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(gy, header, directives)
+PUT_GRAPHIC_WIDGET_INT(gy, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(gy, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(gy, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(gy, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(gy, voice, voice_directives)
 
 
-PUT_GRAPHIC(chord);
-PUT_GRAPHIC(note);
+PUT_GRAPHIC_WIDGET_INT(override, score, directives)
+PUT_GRAPHIC_WIDGET_INT(override, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(override, header, directives)
+PUT_GRAPHIC_WIDGET_INT(override, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(override, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(override, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(override, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(override, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(width, score, directives)
+PUT_GRAPHIC_WIDGET_INT(width, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(width, header, directives)
+PUT_GRAPHIC_WIDGET_INT(width, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(width, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(width, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(width, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(width, voice, voice_directives)
+
+PUT_GRAPHIC_WIDGET_INT(height, score, directives)
+PUT_GRAPHIC_WIDGET_INT(height, scoreheader, directives)
+PUT_GRAPHIC_WIDGET_INT(height, header, directives)
+PUT_GRAPHIC_WIDGET_INT(height, paper, directives)
+PUT_GRAPHIC_WIDGET_INT(height, layout, directives)
+PUT_GRAPHIC_WIDGET_INT(height, movementcontrol, directives)
+PUT_GRAPHIC_WIDGET_INT(height, staff, staff_directives)
+PUT_GRAPHIC_WIDGET_INT(height, voice, voice_directives)
+
+#undef PUT_GRAPHIC_WIDGET_STR
+#undef PUT_GRAPHIC_WIDGET_INT
 
-#define PUT_GRAPHIC_WIDGET(what, directives) PUT_GRAPHIC_WIDGET_FUNC(graphic, graphic_name, what, directives)
-#define PUT_DISPLAY_FUNC(what, directives) PUT_GRAPHIC_WIDGET_FUNC(display, display, what, directives)
-PUT_GRAPHIC_WIDGET(score, directives);
-PUT_GRAPHIC_WIDGET(staff, staff_directives);
-PUT_GRAPHIC_WIDGET(voice, voice_directives);
-PUT_GRAPHIC_WIDGET(scoreheader, directives);
-PUT_GRAPHIC_WIDGET(header, directives);
-PUT_GRAPHIC_WIDGET(paper, directives);
-PUT_GRAPHIC_WIDGET(layout, directives);
-PUT_GRAPHIC_WIDGET(movementcontrol, directives);
 
-PUT_DISPLAY_FUNC(score, directives);
-PUT_DISPLAY_FUNC(staff, staff_directives);
-PUT_DISPLAY_FUNC(voice, voice_directives);
-PUT_DISPLAY_FUNC(scoreheader, directives);
-PUT_DISPLAY_FUNC(header, directives);
-PUT_DISPLAY_FUNC(paper, directives);
-PUT_DISPLAY_FUNC(layout, directives);
-PUT_DISPLAY_FUNC(movementcontrol, directives);
 
-#undef PUT_GRAPHIC_WIDGET
-#undef PUT_DISPLAY_FUNC
-#undef PUT_GRAPHIC_WIDGET_FUNC
 
 
 
@@ -1185,7 +1439,7 @@ standalone_directive_put_graphic(gchar *tag, gchar *value) {
         directive->tag = g_string_new(tag);
 	object_insert(Denemo.gui, obj);
   }
-  if( loadGraphicItem(value, &directive->graphic, &directive->width, &directive->height)) {
+  if( loadGraphicItem(value, (GdkBitmap **)&directive->graphic, &directive->width, &directive->height)) {
     if(directive->graphic_name)
       g_string_assign(directive->graphic_name, value);
     else
@@ -1510,7 +1764,52 @@ ADD_INTTEXT(gy);
 }
 
 
+/* callback to get an upload script of name tag */
+static void upload_edit_script_cb (GtkWidget *widget, gchar *tag) {
+  gchar *filename = get_editscript_filename(tag);
+  if(filename){
+    GError *error = NULL;
+    gchar *script;
+    if(g_file_get_contents (filename, &script, NULL, &error))
+      upload_edit_script(tag, script);
+    g_free(script);
+    g_free(filename);
+  }
+}
 
+/* callback to get an edit script of name tag */
+static void get_edit_script (GtkWidget *widget, gchar *tag) {
+  gchar *filename = get_editscript_filename(tag);
+  if(filename){
+    GError *error = NULL;
+    gchar *script;
+    if(g_file_get_contents (filename, &script, NULL, &error))
+      appendSchemeText(script);
+    else
+      g_warning("Could not get contents of %s\n", filename);
+    g_free(script);
+    g_free(filename);
+  }
+}
+
+
+/* callback to save the scheme script text buffer as an edit script of name tag in the user's local denemo directory */
+static void put_edit_script (GtkWidget *widget, gchar *tag) {
+  gchar *filename = g_build_filename(locatedotdenemo(), "actions", "editscripts", tag, NULL);
+  if((!g_file_test(filename, G_FILE_TEST_EXISTS)) ||
+     confirm("There is already an edit script for this tag", "Do you want to replace it?")){
+    gchar *scheme = (gchar*)getSchemeText();
+    if(scheme && *scheme) {
+      FILE *fp = fopen(filename, "w");
+      if(fp) {
+	fprintf (fp, "%s", scheme);
+	fclose(fp);
+	infodialog("Wrote edit script file to ~/.denemo/editscripts");
+      }
+      g_free(scheme);
+    }
+  }
+}
 
 
 /* text_edit_directive
@@ -1540,6 +1839,7 @@ static gboolean text_edit_directive(DenemoDirective *directive, gchar *what) {
   GString *entrycontent = g_string_new("");
   GtkWidget *entrywidget;
   GtkWidget *label;
+  GtkWidget *button;
 #define TEXTENTRY(thelabel, field) \
   GtkWidget *field;\
   hbox = gtk_hbox_new (FALSE, 8);\
@@ -1595,6 +1895,22 @@ static gboolean text_edit_directive(DenemoDirective *directive, gchar *what) {
   TEXTENTRY("MidiBytes", midibytes);
   NEWINTENTRY("Override Mask", override);
 #undef TEXTENTRY
+  hbox = gtk_hbox_new (FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
+  button = gtk_button_new_with_label("Get Edit Script");
+  gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+  g_signal_connect(G_OBJECT(button),"clicked",  G_CALLBACK(get_edit_script), directive->tag->str);
+  button = gtk_button_new_with_label("Put Edit Script");
+  gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+  g_signal_connect(G_OBJECT(button),"clicked",  G_CALLBACK(put_edit_script), directive->tag->str);
+
+  button = gtk_button_new_with_label("Upload Edit Script");
+  gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+  g_signal_connect(G_OBJECT(button),"clicked",  G_CALLBACK(upload_edit_script_cb), directive->tag->str);
+  button = gtk_check_button_new_with_label("Show Current Script");
+  gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+  gtk_action_connect_proxy(gtk_ui_manager_get_action (Denemo.ui_manager, "/MainMenu/ViewMenu/ToggleScript"), button);
+
   gtk_widget_show_all (dialog);
   gint response = gtk_dialog_run (GTK_DIALOG (dialog));
   g_print("Got response %d\n", response);
@@ -1626,9 +1942,9 @@ if(directive->field && directive->field->len==0) g_string_free(directive->field,
     directive->tag = g_string_new(UNKNOWN_TAG);
   if(directive->graphic){
     if(GTK_IS_WIDGET(directive->graphic))
-      label_widget(directive, NULL, NULL);
+      widget_for_directive(directive, NULL);
     else
-      loadGraphicItem (directive->graphic_name->str, &directive->graphic,  &directive->width, &directive->height);
+      loadGraphicItem (directive->graphic_name->str,  (GdkBitmap **)&directive->graphic,  &directive->width, &directive->height);
   }
   gtk_widget_destroy (dialog);
   if(response==CREATE_SCRIPT)
@@ -1636,41 +1952,30 @@ if(directive->field && directive->field->len==0) g_string_free(directive->field,
   return ret;
 }
 
+
 /* allow edit of a directive, either via script or textually if no script exists 
    return FALSE if user confirms a request to delete the directive
 */
 static gboolean
 edit_directive(DenemoDirective *directive, gchar *what) {
   gboolean ret = TRUE;
-  gchar *name = g_strconcat(directive->tag->str, ".scm", NULL);
-  gchar* filename = g_build_filename (locatedotdenemo(), "actions", "editscripts", name, NULL);
-  if(!g_file_test(filename, G_FILE_TEST_EXISTS)) {
-    g_free(filename);
-    filename = g_build_filename(get_data_dir(), "actions", "editscripts", name, NULL);
-    if(!g_file_test(filename, G_FILE_TEST_EXISTS)) {
-      g_free(filename);
-      filename = g_build_filename (locatedotdenemo(), "download", "actions", "editscripts", name, NULL);
-      if(!g_file_test(filename, G_FILE_TEST_EXISTS)){
-	ret =( text_edit_directive(directive, what)  || !confirm("Directive Delete", "Are you sure you want to delete the directive?"));
-	g_free(filename);
-	score_status (Denemo.gui, TRUE);
-	return ret;
-      }
-    }
-  }
-  GError *error = NULL;
-  gchar *script;
-  if(g_file_get_contents (filename, &script, NULL, &error)) {
-    call_out_to_guile(script);
-    g_free(script);
+  gchar* filename = get_editscript_filename(directive->tag->str);
+  if(filename == NULL) {
+    ret =( text_edit_directive(directive, what)  || !confirm("Directive Delete", "Are you sure you want to delete the directive?"));
+    score_status (Denemo.gui, TRUE);
+    return ret;
   }
+  GError *error = (GError*)execute_script_file(filename);
+  if(error) g_warning(error->message);
   g_free(filename);
   return ret;
 }
 
 
 static void edit_directive_callback(GtkWidget *w, gpointer what) {
-  DenemoDirective *directive = g_object_get_data(w, "directive");
+  DenemoDirective *directive = g_object_get_data(G_OBJECT(w), "directive");
+
+#if 0
   if(!edit_directive(directive, what)){
     if(what == score_directive_put_graphic)
       delete_score_directive(directive->tag->str);
@@ -1696,14 +2001,29 @@ static void edit_directive_callback(GtkWidget *w, gpointer what) {
 	  if(what == movementcontrol_directive_put_graphic)
 	    delete_movementcontrol_directive(directive->tag->str);
 	  else
-
-
-
-
 	    g_warning("Not implemented");
-    
-    
-  }    
+  }
+#else
+#define DO_TYPE(score)\
+    if(what == score##_directive_put_graphic){\
+      if(!edit_directive(directive, #score))\
+	delete_##score##_directive(directive->tag->str);\
+    }
+
+    DO_TYPE(score);
+    DO_TYPE(staff);
+    DO_TYPE(voice);
+    DO_TYPE(scoreheader);
+    DO_TYPE(header);
+    DO_TYPE(paper);
+    DO_TYPE(layout);
+    DO_TYPE(movementcontrol);
+#undef DO_TYPE
+#endif
+
+
+
+  
  }
 
 
@@ -2124,13 +2444,7 @@ GET_STR_FIELD_FUNC(timesig, display)
 
 
 
-PUT_INT_FIELD_FUNC(scoreheader, x)
-PUT_INT_FIELD_FUNC(scoreheader, y)
-PUT_INT_FIELD_FUNC(scoreheader, tx)
-PUT_INT_FIELD_FUNC(scoreheader, ty)
-PUT_INT_FIELD_FUNC(scoreheader, gx)
-PUT_INT_FIELD_FUNC(scoreheader, gy)
-PUT_INT_FIELD_FUNC(scoreheader, override)
+
 GET_INT_FIELD_FUNC(scoreheader, x)
 GET_INT_FIELD_FUNC(scoreheader, y)
 GET_INT_FIELD_FUNC(scoreheader, tx)
@@ -2141,10 +2455,6 @@ GET_INT_FIELD_FUNC(scoreheader, override)
 GET_INT_FIELD_FUNC(scoreheader, width)
 GET_INT_FIELD_FUNC(scoreheader, height)
 
-     //PUT_GRAPHIC(scoreheader)
-
-PUT_STR_FIELD_FUNC(scoreheader, prefix)
-PUT_STR_FIELD_FUNC(scoreheader, postfix)
 
 
 GET_STR_FIELD_FUNC(scoreheader, prefix)
@@ -2152,13 +2462,7 @@ GET_STR_FIELD_FUNC(scoreheader, postfix)
 GET_STR_FIELD_FUNC(scoreheader, display)
 
 
-PUT_INT_FIELD_FUNC(header, x)
-PUT_INT_FIELD_FUNC(header, y)
-PUT_INT_FIELD_FUNC(header, tx)
-PUT_INT_FIELD_FUNC(header, ty)
-PUT_INT_FIELD_FUNC(header, gx)
-PUT_INT_FIELD_FUNC(header, gy)
-PUT_INT_FIELD_FUNC(header, override)
+
 GET_INT_FIELD_FUNC(header, x)
 GET_INT_FIELD_FUNC(header, y)
 GET_INT_FIELD_FUNC(header, tx)
@@ -2169,10 +2473,7 @@ GET_INT_FIELD_FUNC(header, override)
 GET_INT_FIELD_FUNC(header, width)
 GET_INT_FIELD_FUNC(header, height)
 
-     //PUT_GRAPHIC(header)
 
-PUT_STR_FIELD_FUNC(header, prefix)
-PUT_STR_FIELD_FUNC(header, postfix)
 
 
 GET_STR_FIELD_FUNC(header, prefix)
@@ -2180,13 +2481,6 @@ GET_STR_FIELD_FUNC(header, postfix)
 GET_STR_FIELD_FUNC(header, display)
 
 
-PUT_INT_FIELD_FUNC(paper, x)
-PUT_INT_FIELD_FUNC(paper, y)
-PUT_INT_FIELD_FUNC(paper, tx)
-PUT_INT_FIELD_FUNC(paper, ty)
-PUT_INT_FIELD_FUNC(paper, gx)
-PUT_INT_FIELD_FUNC(paper, gy)
-PUT_INT_FIELD_FUNC(paper, override)
 GET_INT_FIELD_FUNC(paper, x)
 GET_INT_FIELD_FUNC(paper, y)
 GET_INT_FIELD_FUNC(paper, tx)
@@ -2197,22 +2491,13 @@ GET_INT_FIELD_FUNC(paper, override)
 GET_INT_FIELD_FUNC(paper, width)
 GET_INT_FIELD_FUNC(paper, height)
 
-     //PUT_GRAPHIC(paper)
 
-PUT_STR_FIELD_FUNC(paper, prefix)
-PUT_STR_FIELD_FUNC(paper, postfix)
 
 
 GET_STR_FIELD_FUNC(paper, prefix)
 GET_STR_FIELD_FUNC(paper, postfix)
 GET_STR_FIELD_FUNC(paper, display)
-PUT_INT_FIELD_FUNC(layout, x)
-PUT_INT_FIELD_FUNC(layout, y)
-PUT_INT_FIELD_FUNC(layout, tx)
-PUT_INT_FIELD_FUNC(layout, ty)
-PUT_INT_FIELD_FUNC(layout, gx)
-PUT_INT_FIELD_FUNC(layout, gy)
-PUT_INT_FIELD_FUNC(layout, override)
+
 GET_INT_FIELD_FUNC(layout, x)
 GET_INT_FIELD_FUNC(layout, y)
 GET_INT_FIELD_FUNC(layout, tx)
@@ -2223,25 +2508,10 @@ GET_INT_FIELD_FUNC(layout, override)
 GET_INT_FIELD_FUNC(layout, width)
 GET_INT_FIELD_FUNC(layout, height)
 
-     //PUT_GRAPHIC(layout)
-
-PUT_STR_FIELD_FUNC(layout, prefix)
-PUT_STR_FIELD_FUNC(layout, postfix)
-
 
 GET_STR_FIELD_FUNC(layout, prefix)
 GET_STR_FIELD_FUNC(layout, postfix)
 GET_STR_FIELD_FUNC(layout, display)
-
-
-
-PUT_INT_FIELD_FUNC(movementcontrol, x)
-PUT_INT_FIELD_FUNC(movementcontrol, y)
-PUT_INT_FIELD_FUNC(movementcontrol, tx)
-PUT_INT_FIELD_FUNC(movementcontrol, ty)
-PUT_INT_FIELD_FUNC(movementcontrol, gx)
-PUT_INT_FIELD_FUNC(movementcontrol, gy)
-PUT_INT_FIELD_FUNC(movementcontrol, override)
 GET_INT_FIELD_FUNC(movementcontrol, x)
 GET_INT_FIELD_FUNC(movementcontrol, y)
 GET_INT_FIELD_FUNC(movementcontrol, tx)
@@ -2252,10 +2522,7 @@ GET_INT_FIELD_FUNC(movementcontrol, override)
 GET_INT_FIELD_FUNC(movementcontrol, width)
 GET_INT_FIELD_FUNC(movementcontrol, height)
 
-     //PUT_GRAPHIC(movementcontrol)
 
-PUT_STR_FIELD_FUNC(movementcontrol, prefix)
-PUT_STR_FIELD_FUNC(movementcontrol, postfix)
 
 
 GET_STR_FIELD_FUNC(movementcontrol, prefix)
@@ -2308,4 +2575,7 @@ TEXT_EDIT_DIRECTIVE(header);
 TEXT_EDIT_DIRECTIVE(paper);
 TEXT_EDIT_DIRECTIVE(layout);
 TEXT_EDIT_DIRECTIVE(movementcontrol);
+TEXT_EDIT_DIRECTIVE(standalone);
+
+
 #undef TEXT_EDIT_DIRECTIVE
