@@ -35,13 +35,11 @@
 #include <dirent.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-#include "midiseq.h"
 #include <libguile.h>
 #include "view.h"
 #include "exportxml.h"
 #include "runsilent.h"
 #include "utils.h"
-#include "alsaplayback.h"
 #ifdef _HAVE_JACK_
 #include "jackmidi.h"
 #endif
@@ -51,8 +49,15 @@
 #endif
 
 struct DenemoRoot Denemo;
-midi_seq *sq;
 
+/* just a simple check, if the user has never run denemo before
+   better, keep this for whole first session? */
+gboolean first_time_user(void) {
+  gchar *filename = g_build_filename(locatedotdenemo(), "denemorc", NULL);
+  gboolean ret = !g_file_test (filename, G_FILE_TEST_EXISTS);
+  g_free(filename);
+  return ret;
+}
 
 static const GtkStockItem denemo_stock_items[] = {
   {"denemo-staccato", N_("Staccato"), (GdkModifierType) 0, 0, NULL},
@@ -114,7 +119,8 @@ register_stock_icon (GtkIconFactory * icon_factory, const gchar * stock_id,
       g_warning (_("Could not load specified pixbuf:\n%s\n"),
                  error->message);
       g_error_free (error);
-      warningdialog("some icons will not display properly, but program will run ok.");
+      if(first_time_user())
+	warningdialog("some icons will not display properly, but program will run ok.");
       warned = TRUE;
     }
   if(pixbuf != NULL) {
@@ -410,10 +416,6 @@ int
 main (int argc, char *argv[])
 {
 
-  GError *error = NULL;
-  /* gtk initialization */
-  gtk_init (&argc, &argv);
-
 //#ifdef G_OS_WIN32
 //  /* workaround necessary for compilation on Cygwin */
 //  g_set_print_handler ((GPrintFunc)printf);
@@ -427,12 +429,47 @@ main (int argc, char *argv[])
   /* initialization of directory relocatability */
   initdir();
 #ifdef G_OS_WIN32
-  gchar *scmcode = g_build_filename(get_data_dir(), "share", "guile", NULL);
-  if(g_file_test(scmcode, G_FILE_TEST_EXISTS)) {
-  g_setenv("GUILE_LOAD_PATH", scmcode, TRUE);
-  g_print("Set environment variable GUILE_LOAD_PATH to %s\n", scmcode);
-  } else warningdialog("You may need to set GUILE_LOAD_PATH to the directory where you have ice9 installed\n");
+  gchar *prefix = g_win32_get_package_installation_directory (NULL, NULL);
+  gchar *guile = g_build_filename (prefix, "share", "guile", NULL);
+  gchar *guile_1_8 = g_build_filename (guile, "1.8", NULL);
+  if (g_file_test (guile, G_FILE_TEST_EXISTS))
+    {
+      gchar *guile_path = g_strconcat (guile, ";", guile_1_8, NULL);
+      g_setenv ("GUILE_LOAD_PATH", guile_path, TRUE);
+      g_print ("Setting GUILE_LOAD_PATH=%s\n", guile_path);
+    }
+  else
+    warningdialog ("You may need to set GUILE_LOAD_PATH to the directory where you have ice9 installed\n");
+  g_setenv ("PANGO_PREFIX", prefix, TRUE);
+  g_setenv ("PANGO_MODULE_VERSION", "1.6.0", TRUE);
+  g_setenv ("PANGO_SO_EXTENSION", ".dll", TRUE);
+  g_print ("Setting PANGO_PREFIX=%s\n", prefix);
+
+  g_setenv ("GTK_MODULE_VERSION", "2.10.0", TRUE);
+  g_setenv ("GTK_SO_EXTENSION", ".dll", TRUE);
+  g_setenv ("GTK_PREFIX", prefix, TRUE);
+  g_print ("Setting GTK_PREFIX=%s\n", prefix);
+
+  gchar *fc_path = g_strconcat (prefix, "/etc/fonts", NULL);
+  g_setenv ("FONTCONFIG_PATH", fc_path, TRUE);
+  g_print ("Setting FONTCONFIG_PATH=%s\n", fc_path);
+  gchar *fc_file = g_strconcat (fc_path, "/fonts.conf", NULL);
+  g_setenv ("FONTCONFIG_FILE", fc_file, TRUE);
+  g_print ("Setting FONTCONFIG_FILE=%s\n", fc_file);
+
+
+  gchar *program_files =  g_getenv("PROGRAMFILES");
+  gchar *path = g_getenv ("PATH");
+  path = g_strconcat (path, ";", program_files, "/Windows Media Player", NULL);
+  path = g_strconcat (path, ";", program_files, "/Adobe/Reader 8.0/Reader", NULL);
+  path = g_strconcat (path, ";", program_files, "/Adobe/Reader 9.0/Reader", NULL);
+  g_setenv ("PATH", path, TRUE);
+
 #endif
+  GError *error = NULL;
+  /* gtk initialization */
+  gtk_init (&argc, &argv);
+
   /* locale initialization */
   //setlocale (LC_CTYPE, "");
   //setlocale (LC_MESSAGES, "");
@@ -443,6 +480,8 @@ main (int argc, char *argv[])
   textdomain (PACKAGE);
 
   register_stock_items ();
+  if(first_time_user())
+    infodialog("Nearly every menu item can be right-clicked, for help, setting keyboard shortcuts and more");
   //g_print("Calling scm boot guile with %d and %p\n", argc, argv);
   scm_boot_guile (argc, argv, inner_main, NULL);
   
@@ -462,34 +501,36 @@ openfile (gchar * name, gboolean template)
   return result;
 }
 
-int process_command_line(int argc, char**argv) {
+gchar * process_command_line(int argc, char**argv) {
 
   gint opts;
   GDir *dir=NULL;
   gchar *filename;
   GError *error = NULL;
+  gchar *initschemefile=NULL,  *commandsetfile=NULL;
   /* parse command line and display help messages */
   gchar *helptext  = g_strconcat (_("\nGNU Denemo version "), VERSION, ".\n\n",
                                  _("\
 Usage: denemo [OPTION]... [FILE]\n\n\
-Run denemo, opening save file FILE\n\n\
-Denemo is a graphical music notation editor. It produces save files\n\
-in GNU Lilypond input format (suitable for immediate typesetting with GNU\n\
-Lilypond) and Adam Tee's JTF file format. Denemo is part of the GNU\n\
-project.\n\n\
+Run denemo, optionally starting with FILE\n\n\
+Denemo is a graphical music notation editor.\n\
+It uses GNU Lilypond for music typesetting\n\
+Denemo is part of the GNU project.\n\n\
 Options:\n\
   -h,--help             print this help and exit\n\
-  -s,--silent           lets just start with silent lilypond conversion\n\
+  -c file               use commandset found in system file\n\
+  -k file               use commandset found in local file (in ~/.denemo)\n\
+  -i pathtofile         process scheme commands in pathtofile on startup\n\
+  -s filename           process scheme commands from system file\n\
   -v,--version          print version number and exit\n\n\n\
 Report bugs to bug-denemo@gnu.org\n"), NULL) ;
 
-  gchar *copytext = _("\
-(c) 1999-2005 Matthew Hiller, Adam Tee, and others\n\n\n\
-This program is provided with absolutely NO WARRANTY; see\n\
-the file COPYING for details.\n\n\
-This software may be redistributed and modified under the\n\
-terms of the GNU General Public License; again, see the file\n\
-COPYING for details.\n\n") ;
+  gchar *copytext = _("(c) 1999-2005, 2009 Matthew Hiller, Adam Tee, and others\n\n\n"
+"This program is provided with absolutely NO WARRANTY; see\n"
+"the file COPYING for details.\n\n"
+"This software may be redistributed and modified under the\n"
+"terms of the GNU General Public License; again, see the file\n"
+"COPYING for details.\n\n");
 
 
 #ifdef HAVE_GETOPT_H
@@ -500,11 +541,12 @@ COPYING for details.\n\n") ;
 #endif
 
 #ifdef HAVE_GETOPT_H
-  while ((opts = getopt_long (argc, argv, "shvt:", long_options, NULL)) != -1)
+  while ((opts = getopt_long (argc, argv, "s:hi:vc:k:", long_options, NULL)) != -1)
 #else
-  while ((opts = getopt (argc, argv, "shvt:")) != -1)
+  while ((opts = getopt (argc, argv, "s:hi:vc:k:")) != -1)
 #endif
     {
+	  g_print("opt %c has %s\n", opts, argv[optind]);
       if (opts == 'h')
         {
           g_print (helptext);
@@ -512,9 +554,20 @@ COPYING for details.\n\n") ;
         }
       else if (opts == 's')
         {
-          g_print (copytext);
-          silentconversion (argv[optind], Denemo.gui);
-          exit (0);
+	  initschemefile = g_build_filename(get_data_dir(), "actions",  optarg, NULL);
+        }
+      else if (opts == 'i')
+        {
+          initschemefile = g_strdup(optarg);
+        }
+
+      else if (opts == 'c')
+        {
+	  commandsetfile = g_build_filename(get_data_dir(), "actions",  optarg, NULL);
+        }
+      else if (opts == 'k')
+        {
+	  commandsetfile = g_build_filename(locatedotdenemo(), "actions",  optarg, NULL);
         }
       else if (opts == 'v')
         {
@@ -531,20 +584,7 @@ COPYING for details.\n\n") ;
   g_free (helptext);
 
 
-
-  /* adapt stock items to denemo */
-  //register_stock_items ();
-  /* Following calls were made previously in newview. However I think they are
-   * global, and should be done once and for all when the application opens
-   * they are now done after initializing guile, at the start of inner_main()
-   * which then calls this procedure.
-   */
-  /* Initialize preferences */
-  //initprefs();
-  /* read history file */
-  //readHistory();
-  /* Set up the keymap */
-  //init_keymap();
+  denemo_scheme_init(initschemefile);
 
 #ifdef _HAVE_JACK_
   g_debug("\nDenemo.prefs.jack_at_startup = %d\n", Denemo.prefs.jack_at_startup);
@@ -577,19 +617,6 @@ COPYING for details.\n\n") ;
   start_init_lash(lash_client);
 #endif
 
-
-
-  //DenemoPrefs prefs;
-  //  readxmlprefs("src/denemorc", &prefs);
-
-#ifdef HAVEALSA
-  if (NULL == (sq = midi_seq_new ("Denemo")))
-    {
-      g_print ("Sequencer Error.\n");
-    }
-#endif
-
-
   /* Set up the signal handler */
   signal (SIGSEGV, denemo_signal_handler);
 #ifdef HAVE_SIGCHLD
@@ -660,27 +687,18 @@ COPYING for details.\n\n") ;
   if (dir)
     g_dir_close (dir);
 
-  gchar *init_file;
-  init_file = g_build_filename(get_data_dir (), "actions", "init.denemo", NULL);
-  if (openfile (init_file, TRUE) == -1)
-    g_warning("Denemo Scheme initialization file %s not found", init_file);
-  init_file = g_build_filename(locatedotdenemo (), "actions", "init.denemo", NULL);
-  (void)openfile (init_file, TRUE);
-  deleteSchemeText();
-  g_free(init_file);
-  /* Open a file, if it was specified on the command line. Note
-   * that this had to be done after the window was created, otherwise
-   * there wouldn't have been a titlebar to set. Also note that
-   * a blank score is created whether or not a load was specified.
-   * This is done this way because the load could bomb out. */
 
-  if (optind < argc)
-    {
-      if (openfile (argv[optind], FALSE) == -1)
-        {
-          g_print ("Attempt to read in file %s failed\n", argv[optind]);
-          return 1;
-        } 
-    } else
-      open_user_default_template(REPLACE_SCORE);
+
+  if(commandsetfile && (0==load_xml_keymap(commandsetfile, TRUE)))
+    ;
+  else
+    load_default_keymap_file();
+
+
+    if (optind < argc)
+      return argv[optind];
+    else
+      return NULL;
+
+
 }
