@@ -71,19 +71,34 @@ initprefs ()
 
   /* Reasonable default values */
 
-  ret->lilypath = g_string_new ("lilypond");
+  ret->csoundcommand = g_string_new ("csound -dm6");
+
+  ret->csoundorcfile = g_string_new ("");
+  const gchar *name = g_get_user_name();
+  ret->username = g_string_new (name?name:"DenemoUser");
+  ret->password = g_string_new ("");
+
+#ifdef G_OS_WIN32
+  ret->browser = g_string_new ("firefox");
+  ret->midiplayer = g_string_new ("wmplayer");
+  ret->audioplayer = g_string_new ("wmplayer");
+  ret->lilypath = g_string_new ("lilypond-windows");
+  ret->pdfviewer = g_string_new ("acrord32");
+  ret->imageviewer = g_string_new ("mspaint");
+  ret->texteditor = g_string_new ("wordpad");
+  ret->midiplayer = g_string_new("wmplayer");
+#else /* !G_OS_WIN32 */
+  ret->browser = g_string_new ("firefox");
   ret->midiplayer = g_string_new ("playmidi");
   ret->audioplayer = g_string_new ("play");
-  ret->csoundcommand = g_string_new ("csound -dm6");
-  ret->browser = g_string_new ("firefox");
-  ret->csoundorcfile = g_string_new ("");
+  ret->lilypath = g_string_new ("lilypond");
   ret->pdfviewer = g_string_new ("xpdf");
+  ret->imageviewer = g_string_new ("eog");
+  ret->texteditor = g_string_new ("xedit");
+#endif /* !G_OS_WIN32 */
   ret->sequencer = g_string_new ("/dev/sequencer");
   ret->midi_in = g_string_new ("/dev/midi");
 
-
-  ret->imageviewer = g_string_new ("eog");
-  ret->texteditor = g_string_new ("xedit");
   ret->denemopath = g_string_new (g_get_home_dir());
   ret->lilyversion = g_string_new (LILYPOND_VERSION);
   ret->temperament = g_string_new("Equal");
@@ -91,8 +106,11 @@ initprefs ()
   ret->resolution = 300;
   ret->overlays = FALSE;
   ret->continuous = TRUE;
-
+#ifdef _HAVE_JACK_
+  ret->immediateplayback = FALSE;
+#else
   ret->immediateplayback = TRUE;
+#endif
   ret->saveparts = FALSE;
   ret->rtcs = TRUE;
   ret->playbackoutput = FALSE;
@@ -213,7 +231,9 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READINTXMLENTRY(autosave)
       
       READXMLENTRY(pdfviewer)
-      READXMLENTRY(imageviewer)           
+      READXMLENTRY(imageviewer)    
+      READXMLENTRY(username)    
+      READXMLENTRY(password)           
       READXMLENTRY(texteditor)            
       READXMLENTRY(denemopath)          
       READXMLENTRY(temperament)
@@ -415,6 +435,8 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEXMLENTRY(csoundorcfile)  
   WRITEXMLENTRY(pdfviewer)
   WRITEXMLENTRY(imageviewer)
+  WRITEXMLENTRY(username)
+  WRITEXMLENTRY(password)
   WRITEXMLENTRY(texteditor) 
   WRITEXMLENTRY(denemopath)
   WRITEXMLENTRY(temperament)
