@@ -8,7 +8,6 @@
 #define PREFOPSH
 
 #include <denemo/denemo.h>
-#include "plugin.h"
 
 #define INITIAL_WIDTH 1000
 #define INITIAL_HEIGHT 500
@@ -16,7 +15,6 @@
 const gchar *locatedotdenemo ();
 
 void initprefs (void);
-GList* get_plugins_list(GList *plugins);
 gint writeXMLPrefs( DenemoPrefs *prefs);
 void writeHistory(void);
 gint readHistory(void);
