@@ -223,6 +223,7 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "SavePart
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ExportPDF"), "ExportPDF", "Export PDF", "Export the score as a PDF document file", export_pdf_action);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ConfigureScore"), "ConfigureScore", "Score Wizard", "Start up a wizard to create a new score. This allows you to set various properties of the score", scorewizard);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PrintPreview"), "PrintPreview", "Print Preview", "Displays the final finished score in your pdf viewer", printpreview_cb);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "PrintSelection"), "PrintSelection", "Print Selection", "Displays selected music from score in your pdf viewer", printselection_cb);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PrintExcerptPreview"), "PrintExcerptPreview", "Print Excerpt", "Displays a musical excerpt in your image viewer", printexcerptpreview_cb);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Print"), "Print", "Print", "Displays the final finished score in a pdf viewer. From this you can print the file using the print command of the viewer", printall_cb);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PrintPart"), "PrintPart", "Print Part", "Displays the final finished score for the current part (that is current staff", printpart_cb);
@@ -239,10 +240,6 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "SaveSele
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Preferences"), "Preferences", "Change Preferences", "Set and save your preferences for how Denemo operates on startup. Edit .denemo/denemorc for missing ones", preferences_change);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SaveAccels"), "SaveAccels", "Save Command Set", "Save the current commands and keyboard shortcuts as the default", save_default_keymap_file_wrapper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "CommandManagement"), "CommandManagement", "Manage Command Set", "View help, change and save keyboard shortcuts", configure_keyboard_dialog);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "LoadPlugins"), "LoadPlugins", "Load Plugins", "Load Plugins", load_plugin);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "UnloadPlugins"), "UnloadPlugins", "Unload Plugins", "Unload Plugins", unloadplugins);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "ListPlugins"), "ListPlugins", "List Plugins", "List the loaded plugins", list_loaded_plugins);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "ListAvailablePlugins"), "ListAvailablePlugins", "List Available Pluigins", "List the available plugins", list_available_plugins);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SwapStaffs"), "SwapStaffs", "Swap Staffs", "Swap this staff with the one higher up. Note this actually swaps voices.", swapstaffs);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SplitVoices"), "SplitVoices", "Split Voices", "Split off the next voice as a separate staff", splitstaffs);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "JoinVoices"), "JoinVoices", "Join Voices", "Merge this staff as a voice on the previous staff", joinstaffs);
@@ -307,7 +304,7 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "NextBook
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PrevBookmark"), "PrevBookmark", "Prev Bookmark", "Go to the previous bookmarked point in the list", prevbookmark);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleEdit"), "ToggleEdit", "Toggle Edit Mode", "Toggle between current mode and edit mode", toggle_edit_mode);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleRest"), "ToggleRest", "Toggle Rest Mode", "Toggle between note entry and rest entry", toggle_rest_mode);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleRhythm"), "ToggleRhythm", "Toggle Rhythm Mode", "Toggle between note entry and rhythm entry", toggle_rhythm_mode);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleRhythm"), "ToggleRhythm", "Toggle Audible Feedback", "Toggle audible feedback on/off", toggle_rhythm_mode);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ClearOverlay"), "ClearOverlay", "Clear Overlay", "Clear the list of pitches that overlay the notes", clear_overlay);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "CreateRhythm"), "CreateRhythm", "Create Rhythm", "Copy selection as a rhythm pattern for notes to follow as they are entered", create_rhythm_cb);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteRhythm"), "DeleteRhythm", "Delete Rhythm", "Delete the selected rhythm pattern", delete_rhythm_cb);
