@@ -7,6 +7,7 @@
  */
 
 #include <stdio.h>
+#include <string.h> /*for SIGTERM */
 #include <gtk/gtk.h>
 #include "accwidths.h"
 #include <denemo/denemo.h>
@@ -42,7 +43,7 @@ warningdialog (gchar * msg)
 {
   GtkWidget *dialog;
 
-  dialog = gtk_message_dialog_new (NULL,
+  dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window),
 				   GTK_DIALOG_DESTROY_WITH_PARENT,
 				   GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, "%s", msg);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
@@ -60,7 +61,7 @@ void
 infodialog (gchar * msg)
 {
   GtkWidget *dialog;
-  dialog = gtk_message_dialog_new (NULL,
+  dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window),
 				   GTK_DIALOG_DESTROY_WITH_PARENT,
 				   GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", msg);
  g_signal_connect_swapped (dialog, "response",
@@ -400,14 +401,14 @@ gchar mid_c_offsettoname (gint mid_c_offset)
   return ((otn + 2) % 7) + 'a';
 }
 
-void *note2lilynotename(struct note *noteobject, GString *ret){
+void note2lilynotename(struct note *noteobject, GString *ret){
   gint mid_c_offset = noteobject->mid_c_offset;
 
   g_string_append_printf (ret, "%c",
 		    mid_c_offsettoname (mid_c_offset));
 }
 
-void *note2lilyaccidental(struct note *noteobject, GString *ret){
+void note2lilyaccidental(struct note *noteobject, GString *ret){
   gint enshift = noteobject->enshift;
   gint k;
   if (enshift < 0)
@@ -418,7 +419,7 @@ void *note2lilyaccidental(struct note *noteobject, GString *ret){
       g_string_append_printf (ret, "is");
 }
 
-void *note2lilyoctave(struct note* noteobject, GString *ret){
+void note2lilyoctave(struct note* noteobject, GString *ret){
   gint mid_c_offset = noteobject->mid_c_offset;
   gint octave = mid_c_offsettooctave (mid_c_offset);
   if (octave < 0)
@@ -429,17 +430,17 @@ void *note2lilyoctave(struct note* noteobject, GString *ret){
       g_string_append_printf (ret, "\'"); 
 }
 
-void *chord2lilyduration(struct chord *chordobject, GString *ret){
+void chord2lilyduration(struct chord *chordobject, GString *ret){
   chord2lilybaseduration(chordobject, ret);
   chord2lilynumdots(chordobject, ret);
 }
 
-void *chord2lilybaseduration(struct chord *chordobject, GString *ret){
+void chord2lilybaseduration(struct chord *chordobject, GString *ret){
   int baseduration = chordobject->baseduration;
   g_string_append_printf (ret,  "%d", baseduration);
 }
 
-void *chord2lilynumdots(struct chord *chordobject, GString *ret){
+void chord2lilynumdots(struct chord *chordobject, GString *ret){
   int numdots = chordobject->numdots;
   g_string_append_printf (ret, "%d",numdots);
 }
@@ -604,7 +605,7 @@ initdir ()
 {
 #ifndef G_OS_WIN32
   GError *error=NULL;
-  if(!gbr_init (&error)&& (error != GBR_INIT_ERROR_DISABLED))
+  if(!gbr_init (&error)&& (error != (GError *)GBR_INIT_ERROR_DISABLED))
     {
       g_print ("BinReloc failed to initialize:\n");
       g_print ("Domain: %d (%s)\n",
@@ -617,6 +618,8 @@ initdir ()
     }
 #endif /* not G_OS_WIN32 */
 }
+extern gchar *
+gbr_find_pkg_data_dir (const gchar * default_pkg_data_dir, const gchar * pkg_name);
 
 const gchar *
 get_data_dir ()
@@ -627,9 +630,11 @@ get_data_dir ()
 #ifdef G_OS_WIN32
     gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
     datadir = g_build_filename (rootdir, "share", "denemo", NULL);
+    g_print ("rootdir=%s\n", rootdir);
+    g_print ("datadir=%s\n", datadir);
     g_free (rootdir);
 #else /* not G_OS_WIN32 */
-  datadir = gbr_find_data_dir (PKGDATADIR);
+    datadir = gbr_find_pkg_data_dir (PKGDATADIR, PKGNAME);
 #endif /* not G_OS_WIN32 */
   }
   return datadir;
@@ -652,24 +657,6 @@ get_conf_dir ()
   return confdir;
 }
 
-const gchar *
-get_plugin_dir ()
-{
-  static gchar *plugindir = NULL;
-  if (plugindir == NULL)
-  {
-#ifdef G_OS_WIN32
-    gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
-    plugindir = g_build_filename (rootdir, "lib", "denemo", NULL);
-    g_free (rootdir);
-#else /* not G_OS_WIN32 */
-    plugindir = gbr_find_lib_dir (PACKAGE_PLUGIN_DIR);
-#endif /* not G_OS_WIN32 */
-  }
-  return plugindir;
-}
-
-
 const gchar *
 get_locale_dir ()
 {
@@ -678,7 +665,7 @@ get_locale_dir ()
   {
 #ifdef G_OS_WIN32
     gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
-    localedir = g_build_filename (rootdir, "share", "locale", "denemo", NULL);
+    localedir = g_build_filename (rootdir, "share", "locale", NULL);
     g_free (rootdir);
 #else /* not G_OS_WIN32 */
 # ifndef ENABLE_BINRELOC
@@ -692,9 +679,7 @@ get_locale_dir ()
      * --enable-binreloc... So, searhing falls back to
      *  $LOCALEDIR/denemo/$LANG which is not a valid path
      */
-    gchar *localedir2 = gbr_find_locale_dir (LOCALEDIR);
-    localedir = g_build_filename (localedir2, "denemo", NULL);
-    g_free (localedir2);
+    localedir = gbr_find_locale_dir (LOCALEDIR);
 # endif /* ENABLE_BINRELOC */
 #endif /* not G_OS_WIN32 */
   }
@@ -924,7 +909,7 @@ confirm (gchar *primary, gchar *secondary)
   GtkWidget *dialog;
   gboolean r = 0;
 
-  dialog = gtk_message_dialog_new (NULL,
+  dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window),
 				   (GtkDialogFlags)
 				   (GTK_DIALOG_MODAL |
 				    GTK_DIALOG_DESTROY_WITH_PARENT),
@@ -960,7 +945,7 @@ void nullify_gstring (GString **s) {
 gchar *
 string_dialog_entry (DenemoGUI *gui, gchar *title, gchar *instruction, gchar *initial_value)
 {
-  string_dialog_entry_with_widget (gui, title, instruction, initial_value, NULL);
+  return string_dialog_entry_with_widget (gui, title, instruction, initial_value, NULL);
 }
 
 /* as string_dialog_entry() but with extra widget */
@@ -1012,7 +997,7 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
 		gtk_widget_destroy (dialog);
 		return NULL;
 	}
-
+  return (gchar *)TRUE;
 }
 
 static gboolean
@@ -1057,3 +1042,11 @@ gchar * get_option(gchar *str, gint length) {
   gtk_widget_destroy(dialog);
   return response;
 }
+
+/* output text to the console window */
+void console_output(gchar *text) {
+  GtkTextIter enditer;
+  GtkTextBuffer *buffer = gtk_text_view_get_buffer((GtkTextView*)(Denemo.console));
+  gtk_text_buffer_get_end_iter (buffer,  &enditer);
+  gtk_text_buffer_insert(buffer, &enditer, text, -1);
+}
