@@ -135,12 +135,12 @@ string_dialog_entry (DenemoGUI *gui, gchar *title, gchar *instruction, gchar *in
 gchar *
 string_dialog_entry_with_widget (DenemoGUI *gui, gchar *title, gchar *instruction, gchar *initial_value, GtkWidget *extra_widget);
 
-void *note2lilynotename(struct note *noteobject, GString *ret);
-void *note2lilyaccidental(struct note *noteobject, GString *ret);
-void *note2lilyoctave(struct note* noteobject, GString *ret);
-void *chord2lilybaseduration(struct chord *chordobject, GString *ret);
-void *chord2lilyduration(struct chord *chordobject, GString *ret);
-void *chord2lilynumdots(struct chord *chordobject, GString *ret);	
+void note2lilynotename(struct note *noteobject, GString *ret);
+void note2lilyaccidental(struct note *noteobject, GString *ret);
+void note2lilyoctave(struct note* noteobject, GString *ret);
+void chord2lilybaseduration(struct chord *chordobject, GString *ret);
+void chord2lilyduration(struct chord *chordobject, GString *ret);
+void chord2lilynumdots(struct chord *chordobject, GString *ret);
 
 #define UTILS_H_PARAM_ASSIGN(param_name) if( (str = g_strstr_len(values->str+i,strlen(values->str+i), #param_name)))\
 nothing=FALSE,param_name = (*(str+strlen(#param_name))=='=')?str+strlen(#param_name)+1:NULL;
@@ -248,5 +248,6 @@ if(!action && param){\
 }
 
 gchar * get_option(gchar *str, gint length);
+void console_output(gchar *text);
 
 #endif /* UTILS_H */
