@@ -39,7 +39,6 @@
 //#include "csoundplayback.h"
 #include "print.h"
 #include "barline.h"
-#include "plugin.h"
 #include "runsilent.h"
 
 #define EXTRA_ACCELS "extra.accels"
@@ -64,13 +63,14 @@ void	  highlight_rest(DenemoGUI *gui, gint dur);
 
 gboolean loadGraphicItem(gchar *name, GdkBitmap **xbm, gint *width, gint *height );
 
-
+void denemo_scheme_init(gchar *initscheme);
 gchar *getSchemeText(void); 
 void deleteSchemeText(void);
 void appendSchemeText(gchar *text);
 void executeScript(void);
+GError *execute_script_file(gchar *filename);
 gint getNumCharsSchemeText(void);
-void
+gboolean
 activate_script (GtkAction *action, gpointer param);
 void 
 create_scheme_function_for_script(gchar *name);
@@ -81,4 +81,9 @@ gchar *
 create_xbm_data_from_pixbuf (GdkPixbuf *pixbuf, int lox, int loy, int hix, int hiy);
 gchar *
 get_icon_for_name(gchar *name, gchar *label);
+
+void
+upload_edit_script(gchar *tag, gchar *script);
+void 
+execute_init_scripts(gchar *menupath);
 #endif
